@@ -1,5 +1,7 @@
 #!/usr/bin/env php
 <?php
+if(function_exists("date_default_timezone_set") and function_exists("date_default_timezone_get"))
+@date_default_timezone_set(@date_default_timezone_get());
 
 $script_start_time = time();
 $panel_type="cronjob";
@@ -13,7 +15,7 @@ function delete_old_files_in_tmp(){
 	global $conf_mysql_db;
 	global $conf_webalizer_country_graph;
 	global $pro_mysql_domain_table;
-	global $conf_dtcshared_path;
+	global $dtcshared_path;
 	global $conf_generated_file_path;
 
 	global $conf_use_webalizer;
@@ -34,7 +36,7 @@ function delete_old_files_in_tmp(){
 		$fullpath = $a["path"]."/".$a["name"]."/subdomains/".$a["subdomain_name"]."/tmp";
 		// Delete files older than 7 days (atime adds one day to the +6...)
 		$cmd = "find $fullpath -atime +6 -exec rm {} \;";
-		exec($cmd);
+		if(file_exists($fullpath)) exec($cmd);
 	}
 }
 
@@ -42,7 +44,7 @@ function make_stats(){
 	global $conf_mysql_db;
 	global $conf_webalizer_country_graph;
 	global $pro_mysql_domain_table;
-	global $conf_dtcshared_path;
+	global $dtcshared_path;
 	global $conf_generated_file_path;
 
 	global $conf_use_webalizer;
@@ -152,7 +154,7 @@ function make_stats(){
 
 							// copy the template file
 							if (!file_exists("$fullpath/visitors.php")){
-								copy("$conf_dtcshared_path/visitors_template/visitors.php", "$fullpath/visitors.php");
+								copy("$dtcshared_path/visitors_template/visitors.php", "$fullpath/visitors.php");
 							}
 						}
 
@@ -211,6 +213,17 @@ fi
 					}else{
 						echo "table empty\n";
 					}
+					// For sites with high traffic and stats to generate - prevent "MySQL server has gone away" error
+					// Check if database still alive
+					$is_db_alive = "SELECT FROM apachelogs.`".$table_name."` WHERE time_stamp='".$end."' LIMIT 0,1";
+					// If not trying reconnect
+					if (!mysql_query($is_db_alive)) {
+						mysql_close();
+						if(connect2base() == false){
+							die("Cannot connect to database !!!");
+						}
+					}
+															
 					$query_dump = "DELETE FROM apachelogs.`".$table_name."` WHERE time_stamp<='".$end."'";
 					$result_dump = mysql_query($query_dump) or die("Cannot execute query \"$query_dump\" file ".__FILE__." line ".__LINE__.": ".mysql_error());
 
@@ -242,7 +255,7 @@ fi
 function make_log_archive (){
 	global $conf_mysql_db;
 	global $pro_mysql_domain_table;
-	global $conf_dtcshared_path;
+	global $dtcshared_path;
 
 	$today_midnight = mktime(0,0,0);
 
