@@ -289,6 +289,7 @@ function restartApache () {
 	global $conf_generated_file_path;
 	global $conf_dtc_system_username;
 	global $conf_dtc_system_groupname;
+	global $dtcshared_path;
 
 	$APACHECTL = searchApachectl();
 	$plop = array();
@@ -296,6 +297,7 @@ function restartApache () {
 	system("chmod +x \"$conf_generated_file_path/vhost_check_dir\"");
 	system("chown $conf_dtc_system_username \"$conf_generated_file_path/vhost_check_dir\"");
 	system("$conf_generated_file_path/vhost_check_dir");
+	system("$dtcshared_path/../admin/remount_aufs");
 	echo "Checking SSL certificates...";
 	system("chown $conf_dtc_system_username \"$conf_generated_file_path/vhost_check_ssl_cert\"");
 	$return_string = exec("$conf_generated_file_path/vhost_check_ssl_cert",$output,$return_val);
@@ -667,6 +669,14 @@ function checkWebalizerCronService () {
 	}
 }
 
+function checkUserCronJob () {
+	$cronjob_table_content = getCronFlags();
+	if($cronjob_table_content["gen_user_cron"] == "yes"){
+		echo "Generating user cron jobs\n";
+		user_cron_generate();
+	}
+}
+
 function printEndTime () {
 	global $script_start_time;
 	$exec_time = time() - $script_start_time;
@@ -709,6 +719,7 @@ if(($start_stamps%(60*60))< 60*10){	updateAllListWebArchive();	}
 // Re-read cronjob values as long as they could have change
 // during this long job calculation !
 checkWebalizerCronService();
+checkUserCronJob();
 $cronjob_table_content = getCronFlags();
 checkTimeAndLaunchNetBackupScript();
 resetLockFlag();
