@@ -111,7 +111,7 @@ error_reporting(E_ALL);
 
 $conf_time_delay_in_seconds=62;
 
-fwrite($log_fp, date("Y-m-d H:m:i")." dtc-stats-daemon starting up...\n");
+fwrite($log_fp, date("Y-m-d H:i:s")." dtc-stats-daemon starting up...\n");
 
 $last_loop = 0;
 // loop until we want to shutdown... 
@@ -123,33 +123,33 @@ while (!$shutdown){
 		// if the time elapsed is less than 10 minutes, sleep until it is
 		if ($time_elapsed_since_last_run < $conf_time_delay_in_seconds){
 			$time_to_sleep = $conf_time_delay_in_seconds - $time_elapsed_since_last_run;
-			fwrite($log_fp, date("Y-m-d H:m:i")." Time since last run $time_elapsed_since_last_run seconds: sleeping for " . $time_to_sleep . " seconds...\n");
+			fwrite($log_fp, date("Y-m-d H:i:s")." Time since last run $time_elapsed_since_last_run seconds: sleeping for " . $time_to_sleep . " seconds...\n");
 			sleep ($time_to_sleep);
 		}else{
-			fwrite($log_fp, date("Y-m-d H:m:i")." Less than one minute since last run: will continue without sleeping...\n");
+			fwrite($log_fp, date("Y-m-d H:i:s")." Less than one minute since last run: will continue without sleeping...\n");
 		}
 	}
 	$last_loop = time();
 
 	if (!mysql_ping()) {
-		fwrite($log_fp, date("Y-m-d H:m:i")." Lost connection to DB! Trying to reconnect...\n");
+		fwrite($log_fp, date("Y-m-d H:i:s")." Lost connection to DB! Trying to reconnect...\n");
 		mysql_close();
 		$ressource_id = mysql_connect($conf_mysql_host, $conf_mysql_login, $conf_mysql_pass);
 		if($ressource_id === FALSE){
-			fwrite($log_fp, date("Y-m-d H:m:i")." ".mysql_error()."\n");
+			fwrite($log_fp, date("Y-m-d H:i:s")." ".mysql_error()."\n");
 			continue;
 		}else{
-			fwrite($log_fp, date("Y-m-d H:m:i")." Reconnect successful!\n");
+			fwrite($log_fp, date("Y-m-d H:i:s")." Reconnect successful!\n");
 			$ressource_db = mysql_select_db($conf_mysql_db);
 			if($ressource_db === FALSE){
-				fwrite($log_fp, date("Y-m-d H:m:i")." ".mysql_error()."\n");
+				fwrite($log_fp, date("Y-m-d H:i:s")." ".mysql_error()."\n");
 			}
 		}
 	}
 
 	$vps_query = "SELECT * FROM $pro_mysql_vps_server_table;";
 	if( ($vps_servers_result = mysql_query($vps_query)) === FALSE){
-		fwrite($log_fp, date("Y-m-d H:m:i")." ".mysql_error()."\n");
+		fwrite($log_fp, date("Y-m-d H:i:s")." ".mysql_error()."\n");
 		continue;
 	}
 	//die("Cannot query $query !!!".mysql_error());
@@ -161,12 +161,12 @@ while (!$shutdown){
 		$vps_servers_row = mysql_fetch_array($vps_servers_result);
 		$vps_server = $vps_servers_row['hostname'];
 
-		fwrite($log_fp, date("Y-m-d H:m:i")." Fetching stats from server $i/$vps_servers_num_rows: $vps_server...\n");
+		fwrite($log_fp, date("Y-m-d H:i:s")." Fetching stats from server $i/$vps_servers_num_rows: $vps_server...\n");
 		$soap_client = connectToVPSServer($vps_server);
 		$r = $soap_client->call("getCollectedPerformanceData",array("count" => 64),"","","");
 		$err = $soap_client->getError();
 		if ($err) {
-			fwrite($log_fp, date("Y-m-d H:m:i")." ".$err);
+			fwrite($log_fp, date("Y-m-d H:i:s")." ".$err);
 			continue;
 		}
 		//
@@ -178,14 +178,14 @@ while (!$shutdown){
 			mkdir("/var/lib/dtc/dtc-xenservers-rrds/$vps_server",0755);
 		}
 		if( !is_array($r) ){
-			fwrite($log_fp, date("Y-m-d H:m:i")." No data in this fetch!\n");
+			fwrite($log_fp, date("Y-m-d H:i:s")." No data in this fetch!\n");
 			continue;
 		}
 
 		// Records are ordered by timestamps, we need something ordered by VPS name,
 		// so we do the maths...
 		$num_records = sizeof($r);
-		fwrite($log_fp, date("Y-m-d H:m:i")." Now ordering $num_records record(s)...\n");
+		fwrite($log_fp, date("Y-m-d H:i:s")." Now ordering $num_records record(s)...\n");
 		for($rec=0;$rec<$num_records;$rec++){
 			$cur = $r[$rec];
 			// If there is no VPS running, then $cur is not an array: we have to test that!
@@ -202,7 +202,7 @@ while (!$shutdown){
 		// Now for each VPS, let's record all data collected
 		$num_vps = sizeof($all_recs);
 		$keys = array_keys($all_recs);
-		fwrite($log_fp, date("Y-m-d H:m:i")." $num_vps VPS...");
+		fwrite($log_fp, date("Y-m-d H:i:s")." $num_vps VPS...");
 		for($vps=0;$vps<$num_vps;$vps++){
 			$vps_name = $keys[$vps];
 			$vps_number = substr($vps_name,3);
@@ -322,7 +322,7 @@ WHERE vps_server_hostname='".$vps_servers_row["hostname"]."' AND vps_xen_name='x
 	mysql_free_result($vps_servers_result);
 }
 fclose($log_fp);
-fwrite($log_fp, date("Y-m-d H:m:i")." dtc-stats-daemon shutting down...\n");
+fwrite($log_fp, date("Y-m-d H:i:s")." dtc-stats-daemon shutting down...\n");
 unlink("/var/run/dtc-stats-daemon.pid");
 
 ?> 
