@@ -32,10 +32,12 @@ $dtc_database = array(
 			"pass_expire" => "int(12) NOT NULL default '0'",
 			"allow_add_domain" => "enum('yes','no','check') NOT NULL default 'check'",
 			"max_domain" => "int(9) NOT NULL default '0'",
+			"shared_hosting_security" => "enum('mod_php','sbox_copy','sbox_aufs') NOT NULL default 'mod_php'",
 			"restricted_ftp_path" => "enum('yes','no') NOT NULL default 'no'",
 			"allow_dns_and_mx_change" => "enum('yes','no') NOT NULL default 'yes'",
 			"allow_mailing_list_edit" => "enum('yes','no') NOT NULL default 'yes'",
 			"allow_subdomain_edit" => "enum('yes','no') NOT NULL default 'yes'",
+			"allow_cronjob_edit" => "enum('yes','no') NOT NULL default 'yes'",
 			"nbrdb" => "int(9) NOT NULL default '1'",
 			"resseller_flag" => "enum('yes','no') NOT NULL default 'no'",
 			"ssh_login_flag" => "enum('yes','no') NOT NULL default 'no'",
@@ -45,6 +47,8 @@ $dtc_database = array(
 			"ob_tail" => "varchar(64) NOT NULL default ''",
 			"ob_next" => "varchar(64) NOT NULL default ''",
 			"last_used_lang" => "varchar(32) NOT NULL default 'en_US.UTF-8'",
+			"recovery_token" => "varchar(64) NOT NULL default ''",
+			"recovery_timestamp" => "int(12) NOT NULL default '0'",
 			"max_ssh" => "int(12) NOT NULL default '3'"
 		),
 		"primary" => "(adm_login)",
@@ -112,7 +116,8 @@ $dtc_database = array(
 			"product_id" => "int(12) NOT NULL default '0'",
 			"payment_id" => "int(12) NOT NULL default '0'",
 			"download_pass" => "varchar(64) NOT NULL default 'none'",
-			"country_code" => "varchar(4) NOT NULL default 'US'",
+			"country_code" => "varchar(255) NOT NULL default 'US'",
+			"services" => "text",
 			"last_expiry_date" => "date NOT NULL default '0000-00-00'"
 		),
 		"primary" => "(id)"
@@ -176,6 +181,7 @@ $dtc_database = array(
 			"named_slavezonefiles_path" => "varchar(255) NOT NULL default 'slave_zones'",
 			"named_zonefiles_path" => "varchar(255) NOT NULL default 'zones'",
 			"send_passwords_in_emails" => "enum('yes','no') NOT NULL default 'no'",
+			"enforce_adm_encryption" => "enum('yes','no') NOT NULL default 'yes'",
 			"autogen_default_subdomains" => "enum('yes','no') NOT NULL default 'yes'",
 			"autogen_subdomain_list" => "varchar(255) NOT NULL default 'pop|imap|mail|smtp|ftp'",
 			"autogen_webmail_alias" => "enum('yes','no') NOT NULL default 'yes'",
@@ -220,6 +226,10 @@ $dtc_database = array(
 			"shared_renewal_after" => "varchar(64) NOT NULL default '15|7'",
 			"shared_renewal_lastwarning" => "varchar(64) NOT NULL default '25'",
 			"shared_renewal_shutdown" => "varchar(64) NOT NULL default '28'",
+			"custom_renewal_before" => "varchar(64) NOT NULL default '5|10'",
+			"custom_renewal_after" => "varchar(64) NOT NULL default '3|7'",
+			"custom_renewal_lastwarning" => "varchar(64) NOT NULL default '12'",
+			"custom_renewal_shutdown" => "varchar(64) NOT NULL default '15'",
 			"webalizer_country_graph" => "enum('yes','no') NOT NULL default 'no'",
 			"apache_version" => "varchar(16) NOT NULL default '1'",
 			"dtc_system_uid" => "varchar(16) NOT NULL default 'CONF_DTC_SYSTEM_UID'",
@@ -280,7 +290,9 @@ $dtc_database = array(
 			"panel_subtitle" => "varchar(255) NOT NULL default 'default'",
 			"panel_logo" => "varchar(255) NOT NULL default 'default'",
 			"this_server_default_tld" => "varchar(10) NOT NULL default '.com'",
-			"panel_logolink" => "varchar(255) NOT NULL default 'default'"
+			"panel_logolink" => "varchar(255) NOT NULL default 'default'",
+			"invoice_scp_addr" => "varchar(255) NOT NULL default ''",
+			"invoice_scp_when" => "enum('day','month') NOT NULL default 'day'"
 		),
 		"keys" => array(
 			"unicrow" => "(unicrow)"
@@ -304,6 +316,7 @@ $dtc_database = array(
 			"gen_backup" => "enum('yes','no') NOT NULL default 'no'",
 			"gen_ssh" => "enum('yes','no') NOT NULL default 'no'",
 			"gen_nagios" => "enum('yes','no') NOT NULL default 'no'",
+			"gen_user_cron" => "enum('yes','no') NOT NULL default 'no'",
 			"lock_flag" => "enum('inprogress','finished') NOT NULL default 'finished'"
 		),
 		"keys" => array(
@@ -323,6 +336,44 @@ $dtc_database = array(
 			"mandatory" => "enum('yes','no') NOT NULL default 'no'"
 		),
 		"primary" => "(id)"
+	),
+		"custom_heb_types" => array(
+		"vars" => array(
+			"id" => "int(11) NOT NULL auto_increment",
+			"name" => "varchar(32) NOT NULL default ''",
+			"reqdomain" => "enum('yes','no') NOT NULL default 'no'"
+		),
+		"primary" => "(id)",
+		"keys" => array(
+			"name" => "(name)"
+		)
+	),
+	"custom_heb_types_fld" => array(
+		"vars" => array(
+			"id" => "int(9) NOT NULL auto_increment",
+			"varname" => "varchar(255) NOT NULL default ''",
+			"question" => "varchar(255) NOT NULL default ''",
+			"widgettype" => "varchar(255) NOT NULL default ''",
+			"widgetvalues" => "varchar(255) NOT NULL default ''",
+			"widgetdisplay" => "varchar(255) NOT NULL default ''",
+			"widgetorder" => "int(9) NOT NULL default '0'",
+			"custom_heb_type_id" => "int(11) NOT NULL default '0'"
+		),
+		"primary" => "(id)"
+	),
+	"custom_product" => array(
+		"vars" => array(
+			"id" => "int(11) NOT NULL auto_increment",
+			"owner" => "varchar(64) NOT NULL default ''",
+			"domain" => "varchar(255) NOT NULL default ''",
+			"start_date" => "date NOT NULL default '0000-00-00'",
+			"expire_date" => "date NOT NULL default '0000-00-00'",
+			"product_id" => "int(9) NOT NULL default '0'",
+			"custom_heb_type" => "int(11) NOT NULL default '0'",
+			"custom_heb_type_fld" => "text",
+			"country_code" => "varchar(4) NOT NULL default 'US'"
+		),
+		"primary" => "(id)"
 	),
 	"dedicated" => array(
 		"vars" => array(
@@ -669,7 +720,7 @@ $dtc_database = array(
 		"vars" => array(
 			"id" => "int(9) NOT NULL auto_increment",
 			"reqadm_login" => "varchar(64) NOT NULL default ''",
-			"reqadm_pass" => "varchar(16) NOT NULL default ''",
+			"reqadm_pass" => "varchar(255) NOT NULL default ''",
 			"domain_name" => "varchar(64) NOT NULL default ''",
 			"family_name" => "varchar(64) NOT NULL default ''",
 			"first_name" => "varchar(64) NOT NULL default ''",
@@ -725,6 +776,7 @@ $dtc_database = array(
 			"product_id" => "int(11) NOT NULL default '0'",
 			"vat_rate" => "decimal(9,2) NOT NULL default '0.00'",
 			"vat_total" => "decimal(9,2) NOT NULL default '0.00'",
+			"services" => "text",
 			"hash_check_key" => "varchar(255) NOT NULL default ''",
 		),
 		"primary" => "(id)",
@@ -749,9 +801,10 @@ $dtc_database = array(
 			"renew_time" => "time NOT NULL default '00:00:00'",
 			"product_id" => "int(11) NOT NULL default '0'",
 			"renew_id" => "int(11) NOT NULL default '0'",
-			"heb_type" => "enum('shared','ssl','vps','server','ssl_renew','shared-upgrade','add-money') NOT NULL default 'shared'",
+			"heb_type" => "enum('shared','ssl','vps','server','custom','ssl_renew','shared-upgrade','add-money','multiple-services') NOT NULL default 'shared'",
+			"services" => "text",
 			"pay_id" => "int(11) NOT NULL default '0'",
-			"country_code" => "varchar(4) NOT NULL default 'US'"
+			"country_code" => "varchar(255) NOT NULL default 'US'"
 		),
 		"primary" => "(id)"
 	),
@@ -818,16 +871,19 @@ $dtc_database = array(
 			"allow_add_domain" => "enum('yes','no','check') NOT NULL default 'no'",
 			"max_domain" => "int(9) NOT NULL default '0'",
 			"restricted_ftp_path" => "enum('yes','no') NOT NULL default 'no'",
+			"shared_hosting_security" => "enum('mod_php','sbox_copy','sbox_aufs') NOT NULL default 'mod_php'",
 			"allow_dns_and_mx_change" => "enum('yes','no') NOT NULL default 'yes'",
 			"allow_mailing_list_edit" => "enum('yes','no') NOT NULL default 'yes'",
 			"allow_subdomain_edit" => "enum('yes','no') NOT NULL default 'yes'",
 			"pkg_install_flag" => "enum('yes','no') NOT NULL default 'yes'",
 			"ftp_login_flag" => "enum('yes','no') NOT NULL default 'yes'",
-			"heb_type" => "enum('shared','ssl','vps','server') NOT NULL default 'shared'",
+			"heb_type" => "enum('shared','ssl','vps','server','custom') NOT NULL default 'shared'",
 			"renew_prod_id" => "int(11) NOT NULL default '0'",
 			"affiliate_kickback" => "varchar(9) NOT NULL default ''",
 			"private" => "enum('yes','no') NOT NULL default 'no'",
-			"use_radius" => "enum('yes','no') NOT NULL default 'no'"
+			"use_radius" => "enum('yes','no') NOT NULL default 'no'",
+			"custom_heb_type" => "int(11) NOT NULL default '0'",
+			"custom_heb_type_fld" => "text"
 		),
 		"primary" => "(id)",
 		"keys" => array(
@@ -1036,7 +1092,8 @@ $dtc_database = array(
 			"dineromail_nrocuenta" => "varchar(20) NOT NULL default ''",
 			"dineromail_tipospago" => "varchar(30) NOT NULL default '2,7,13,4,5,6,14,15,16,17,18'",
 			"dineromail_cargocomision" => "decimal(9,2) NOT NULL default '0.00'",
-			"dineromail_porcentajecomision" => "decimal(9,2) NOT NULL default '0.00'"
+			"dineromail_porcentajecomision" => "decimal(9,2) NOT NULL default '0.00'",
+			"dineromail_logo_url" => "varchar(255) NOT NULL default ''"
 		),
 		"keys" => array(
 			"unicrow" => "(unicrow)"
@@ -1159,7 +1216,7 @@ $dtc_database = array(
 			"bcred" => "int(2) NOT NULL default '1'",
 			"flogs" => "int(11) NOT NULL default '0'",
 			"size" => "int(11) NOT NULL default '0'",
-			"shell" => "varchar(64) NOT NULL default '/bin/dtc-chroot-shell'",
+			"shell" => "varchar(64) NOT NULL default '/usr/bin/dtc-chroot-shell'",
 			"hostname" => "varchar(64) NOT NULL default 'anotherlight.com'",
 			"vhostip" => "varchar(16) NOT NULL default '0.0.0.0'",
 			"login_count" => "int(11) NOT NULL default '0'",
@@ -1202,6 +1259,8 @@ $dtc_database = array(
 			"id" => "int(12) NOT NULL auto_increment",
 			"safe_mode" => "enum('yes','no') NOT NULL default 'yes'",
 			"sbox_protect" => "enum('yes','no') NOT NULL default 'yes'",
+			"shared_hosting_security" => "enum('mod_php','sbox_copy','sbox_aufs') NOT NULL default 'mod_php'",
+			"shared_hosting_varwww_docroot" => "enum('yes','no') NOT NULL default 'no'",
 			"domain_name" => "varchar(255) NOT NULL default ''",
 			"subdomain_name" => "varchar(255) NOT NULL default ''",
 			"path" => "varchar(64) NOT NULL default ''",
@@ -1314,9 +1373,9 @@ $dtc_database = array(
 			"subdomain_name" => "varchar(255) NOT NULL default ''",
 			"minute" => "varchar(4) NOT NULL default '0'",
 			"hour" => "varchar(4) NOT NULL default '0'",
-			"day_of_month" => "varchar(2) NOT NULL default '0'",
-			"mon" => "varchar(2) NOT NULL default '0'",
-			"dow" => "varchar(2) NOT NULL default '0'",
+			"day_of_month" => "varchar(4) NOT NULL default '0'",
+			"mon" => "varchar(4) NOT NULL default '0'",
+			"dow" => "varchar(4) NOT NULL default '0'",
 			"uri" => "varchar(128) NOT NULL default 'my_cron.php?param=value'"
 		),
 		"primary" => "(id)"
