@@ -22,8 +22,15 @@ function DTCRMlistClients(){
 	$text = "<div style=\"white-space: nowrap\" nowrap>
 <a href=\"?rub=crm&id=0\">". _("New customer") ."</a>
 </a><br><br>";
+	if(!isset($_REQUEST["clientsearch_txt"])){
+		$_REQUEST["clientsearch_txt"] = '';
+	}
+	if($clientlist_type == "search" && preg_match("/^[a-zA-Z0-9\_\-\@\.\ ].*$/", $_REQUEST["clientsearch_txt"])){
+		$query = "SELECT * FROM $pro_mysql_client_table WHERE UCASE(company_name) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') OR UCASE(familyname) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') OR UCASE(christname) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') OR UCASE(email) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') OR UCASE(phone) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') OR UCASE(special_note) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') OR UCASE(customfld) LIKE UCASE('%".mysql_real_escape_string($_REQUEST["clientsearch_txt"])."%') ORDER BY familyname";
+	}else{
+		$query = "SELECT * FROM $pro_mysql_client_table ORDER BY familyname";
+	}
 
-	$query = "SELECT * FROM $pro_mysql_client_table ORDER BY familyname";
 	$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
 	$num_rows = mysql_num_rows($result);
 	$client_list = array();
@@ -89,9 +96,15 @@ function DTCRMlistClients(){
 	if($clientlist_type == "hide-no-admins"){
 		$selectedlist_hide_no_admin = " selected";
 		$selectedlist_show_all = "";
-	}else{
+		$selectedlist_search = "";
+	}elseif($clientlist_type == "show-all"){
+ 		$selectedlist_hide_no_admin = "";
+ 		$selectedlist_show_all = " selected";
+		$selectedlist_search = "";
+	}else{ // search
 		$selectedlist_hide_no_admin = "";
-		$selectedlist_show_all = " selected";
+		$selectedlist_show_all = "";
+		$selectedlist_search = " selected";
 	}
        $list_prefs = "<div class=\"box_wnb_nb_content\">
 <div style=\"white-space: nowrap\" nowrap><form action=\"?\"><font size=\"-2\">". _("Show:")  ."<br>
@@ -99,7 +112,9 @@ function DTCRMlistClients(){
 <select class=\"box_wnb_nb_input\" name=\"clientlist_type\">
 <option value=\"hide-no-admins\"$selectedlist_hide_no_admin>". _("Hide client without admin") ."
 <option value=\"show-all\"$selectedlist_show_all>"._("Show all")."
-</select>
+<option value=\"search\"$selectedlist_search>"._("Search")."</option>
+</select><br /><br />". _("Search string:") ."<br />
+<input class=\"box_wnb_nb_input\" type=\"text\" name=\"clientsearch_txt\">
 <div class=\"box_wnb_nb_input_btn_container\" onMouseOver=\"this.className='box_wnb_nb_input_btn_container-hover';\" onMouseOut=\"this.className='box_wnb_nb_input_btn_container';\">
  <div class=\"box_wnb_nb_input_btn_left\"></div>
  <div class=\"box_wnb_nb_input_btn_mid\"><input class=\"box_wnb_nb_input_btn\" type=\"submit\" value=\""._("Ok")."\"></div>
@@ -208,12 +223,12 @@ function DTCRMeditClients(){
 <input type=\"hidden\" name=\"id\" value=\"$cid\">$hidden_inputs
 ";
 	$text .= dtcFormTableAttrs();
-	$text .= dtcFormLineDraw( _("Familly name: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_familyname\"value=\"".htmlspecialchars(stripcslashes($row["familyname"]))."\">");
-	$text .= dtcFormLineDraw( _("First name: ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_christname\" value=\"".htmlspecialchars(stripcslashes($row["christname"]))."\">",0);
-	$text .= dtcFormLineDraw( _("Is it a company: ") ,"<input type=\"radio\" name=\"ed_is_company\" value=\"yes\" $iscomp_yes > "._("Yes")."
+	$text .= dtcFormLineDraw( _("Last Name: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_familyname\"value=\"".htmlspecialchars(stripcslashes($row["familyname"]))."\">");
+	$text .= dtcFormLineDraw( _("First Name: ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_christname\" value=\"".htmlspecialchars(stripcslashes($row["christname"]))."\">",0);
+	$text .= dtcFormLineDraw( _("Company Account: ") ,"<input type=\"radio\" name=\"ed_is_company\" value=\"yes\" $iscomp_yes > "._("Yes")."
 <input type=\"radio\" name=\"ed_is_company\" value=\"no\" $iscomp_no > "._("No"));
-	$text .= dtcFormLineDraw( _("Company name: ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_company_name\" value=\"".htmlspecialchars(stripcslashes($row["company_name"]))."\">",0);
-	$text .= dtcFormLineDraw( _("VAT number: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_vat_num\" value=\"".htmlspecialchars(stripcslashes($row["vat_num"]))."\">");
+	$text .= dtcFormLineDraw( _("Company Name: ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_company_name\" value=\"".htmlspecialchars(stripcslashes($row["company_name"]))."\">",0);
+	$text .= dtcFormLineDraw( _("VAT Number: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_vat_num\" value=\"".htmlspecialchars(stripcslashes($row["vat_num"]))."\">");
 	$text .= dtcFormLineDraw( _("Address (line1): ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_addr1\" value=\"".htmlspecialchars(stripcslashes($row["addr1"]))."\">",0);
 	$text .= dtcFormLineDraw( _("Address (line2): ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_addr2\" value=\"".htmlspecialchars(stripcslashes($row["addr2"]))."\">");
 	$text .= dtcFormLineDraw( _("Address (line3): ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_addr3\" value=\"".htmlspecialchars(stripcslashes($row["addr3"]))."\">",0);
@@ -222,10 +237,10 @@ function DTCRMeditClients(){
 	$text .= dtcFormLineDraw( _("State: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_state\" value=\"".htmlspecialchars(stripcslashes($row["state"]))."\">");
 	$text .= dtcFormLineDraw( _("Country: ") ,"<select class=\"dtcDatagrid_input_alt_color\" name=\"ed_country\">".
 cc_code_popup($row["country"])."</select>",0);
-	$text .= dtcFormLineDraw( _("Phone number: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_phone\" value=\"".htmlspecialchars(stripcslashes($row["phone"]))."\">");
+	$text .= dtcFormLineDraw( _("Phone Number: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_phone\" value=\"".htmlspecialchars(stripcslashes($row["phone"]))."\">");
 	$text .= dtcFormLineDraw( _("Fax: ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_fax\" value=\"".htmlspecialchars(stripcslashes($row["fax"]))."\">",0);
 	$text .= dtcFormLineDraw( _("Email: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_email\" value=\"".$row["email"]."\">");
-	$text .= dtcFormLineDraw( _("Notes: ") ,"<textarea class=\"dtcDatagrid_input_alt_color\" cols=\"40\" rows=\"5\" name=\"ed_special_note\">".htmlspecialchars(stripcslashes($specnot))."</textarea>",0);
+	$text .= dtcFormLineDraw( _("Notes: ") ,"<textarea cols=\"60\" rows=\"7\" class=\"dtcDatagrid_input_alt_color\" cols=\"40\" rows=\"5\" name=\"ed_special_note\">".htmlspecialchars(stripcslashes($specnot))."</textarea>",0);
 	$text .= dtcFormLineDraw( _("Money remaining: ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_dollar\" value=\"".$row["dollar"]."\">");
 	$text .= dtcFormLineDraw( _("Quota (MB): ") ,"<input class=\"dtcDatagrid_input_alt_color\" size=\"40\" type=\"text\" name=\"ed_disk_quota_mb\" value=\"".$row["disk_quota_mb"]."\">",0);
 	$text .= dtcFormLineDraw( _("Allowed data transfer (GB): ") ,"<input class=\"dtcDatagrid_input_color\" size=\"40\" type=\"text\" name=\"ed_bw_quota_per_month_gb\" value=\"".$row["bw_quota_per_month_gb"]."\">");
@@ -299,11 +314,11 @@ cc_code_popup($row["country"])."</select>",0);
 			$widget .= "</select>";
 			break;
 		case "textarea":
-			$widget = "<textarea class=\"$css_class\" name=\"".$a["varname"]."\">".htmlspecialchars($val)."</textarea>";
+			$widget = "<textarea cols=\"60\" rows=\"7\" class=\"$css_class\" name=\"".$a["varname"]."\">".htmlspecialchars($val)."</textarea>";
 			break;
 		case "text":
 		default:
-			$widget = "<input class=\"$css_class\" size=\"40\" type=\"text\" name=\"".htmlspecialchars($a["varname"])."\" value=\"".$val."\">";
+			$widget = "<input size=\"60\" class=\"$css_class\" size=\"40\" type=\"text\" name=\"".htmlspecialchars($a["varname"])."\" value=\"".$val."\">";
 			break;
 		}
 		$text .= dtcFormLineDraw($a["question"],$widget,$init_alt);
