@@ -205,11 +205,14 @@ function pro_vhost_generate(){
 	global $conf_use_shared_ssl;
 	$vhost_file = "";
 
+	$aufs_list = "";
+
+	$logrotate_file_chk = array();
 	$logrotate_file = "# Do not edit this file, it's generated
 # edit /etc/dtc/logrotate.template instead!
 ";
 
-$vhost_file .= "# WARNING ! This file is automatically edited by the dtc cron
+$vhost_file_start = "# WARNING ! This file is automatically edited by the dtc cron
 # daemon: do not edit. All manual changes to hosts that are configured within
 # the dtc panel will be removed with the next cron job. It's the same for all
 # files in this folder exept the ssl, the 404 and the template folder.
@@ -223,6 +226,11 @@ $vhost_file .= "# WARNING ! This file is automatically edited by the dtc cron
 # to find this file (somewhere in /etc/httpd or /etc/apache2 or even in
 # /usr/local/etc/apache/httpd.conf ...).
 
+# Loading the php5 module, as we had to disable the default config file which
+# has in /etc/apache2/mods-enabled/php5.conf a SetHandler directive that is
+# conflicting with the one we're using with SBOX
+LoadModule php5_module /usr/lib/apache2/modules/libphp5.so
+
 # Disabling TRACE (for security reasons)
 RewriteEngine on
 RewriteCond %{REQUEST_METHOD} ^(DELETE|TRACE|TRACK)
@@ -312,7 +320,8 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	LogSQLScoreTable $conf_mysql_db.http_accounting
 	DirectoryIndex $conf_apache_directoryindex
 </VirtualHost>\n";
-					$logrotate_file .= "$path_404/logs/error.log ";
+					$logrotate_file_chk[] = "$path_404/logs/error.log";
+					//$logrotate_file .= "$path_404/logs/error.log ";
 				}
 			}
 		}
@@ -370,7 +379,8 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 </VirtualHost>\n\n";	
 		}
 
-    		$logrotate_file .= "$path_404/logs/error.log ";
+		$logrotate_file_chk[] = "$path_404/logs/error.log";
+		// $logrotate_file .= "$path_404/logs/error.log ";
 	    }
 	
 	}
@@ -529,15 +539,11 @@ AND $pro_mysql_admin_table.id_client != '0'";
 			$num_rows2++;
 		}
 
-// This is a bad idea to die in this case
-// because it actualy happen if you redirect www ip to something else.
-//		if($num_rows2 < 1){
-//			die("No subdomain for domain $web_name !");
-//		}
 		for($j=0;$j<$num_rows2;$j++){
 			$subdomain = $temp_array_subs[$j];
 //			$subdomain = mysql_fetch_array($result2) or die ("Cannot fetch user");
 			$web_subname = $subdomain["subdomain_name"];
+			$shared_hosting_subdomain_security = $subdomain["shared_hosting_security"];
 			if( $subdomain["customize_vhost"] == ""){
 				$custom_directives = "";
 			}else{
@@ -669,6 +675,9 @@ AND $pro_mysql_admin_table.id_client != '0'";
 	<Directory $web_path/$web_name/subdomains/$web_subname/html>
 		Allow from all
 	</Directory>
+	<Directory $web_path/$web_name/subdomains/$web_subname/logs>
+		Allow from all
+	</Directory>
 # No ScriptAlias: we want to use system's /usr/lib/cgi-bin !!!
 #	ScriptAlias /cgi-bin $web_path/$web_name/subdomains/$web_subname/cgi-bin
 	ErrorLog $web_path/$web_name/subdomains/$web_subname/logs/error.log
@@ -693,7 +702,8 @@ $vhost_file .= "
 </VirtualHost>
 
 ";
-			$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
+			$logrotate_file_chk[] = "$web_path/$web_name/subdomains/$web_subname/logs/error.log";
+			//$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
 } // - end of for loop
 
 // ---------------------------------------------------
@@ -726,6 +736,11 @@ $vhost_file .= "
 						vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/html");
 						vhost_chk_dir_sh("$web_path/$web_name/subdomains/$web_subname/cgi-bin");
 					}
+					if($webadmin["shared_hosting_security"] == 'sbox_aufs' || ($webadmin["shared_hosting_security"] == 'mod_php' && $subdomain["shared_hosting_security"] == 'sbox_aufs')){
+						vhost_chk_dir_sh("$web_path/$web_name/subdomains.aufs");
+						vhost_chk_dir_sh("$web_path/$web_name/subdomains.aufs/".$web_subname);
+						$aufs_list .= "$web_path/$web_name/subdomains/".$web_subname."\n";
+					}
 					$iteration_table = array();
 					$iteration_table[] = "normal";
 					$ssl_cert_folder_path = "$web_path/$domain_to_get/subdomains/$web_subname/ssl";
@@ -764,26 +779,27 @@ $vhost_file .= "
 
 					$log_tablename = str_replace("-","A",str_replace(".","_",$web_name)).'$'.str_replace("-","A",str_replace(".","_",$web_subname));
 					$vhost_more_conf = "";
+					$php_more_conf = "";
 					if($subdomain["register_globals"] == "yes"){
-						$vhost_more_conf .= "	php_admin_value register_globals 1\n";
+						$php_more_conf .= "	php_admin_value register_globals 1\n";
 					}
 					if($subdomain["php_memory_limit"] != ""){
-						$vhost_more_conf .= "	php_admin_value memory_limit ".$subdomain["php_memory_limit"]."M\n";
+						$php_more_conf .= "	php_admin_value memory_limit ".$subdomain["php_memory_limit"]."M\n";
 					}
 					if($subdomain["php_max_execution_time"] != ""){
-						$vhost_more_conf .= "	php_admin_value max_execution_time ".$subdomain["php_max_execution_time"]."\n";
+						$php_more_conf .= "	php_admin_value max_execution_time ".$subdomain["php_max_execution_time"]."\n";
 					}
 					if($subdomain["php_session_auto_start"] == "yes"){
-						$vhost_more_conf .= "	php_admin_flag session_autostart ".$subdomain["php_session_auto_start"]."\n";
+						$php_more_conf .= "	php_admin_flag session_autostart ".$subdomain["php_session_auto_start"]."\n";
 					}
 					if($subdomain["php_allow_url_fopen"] == "yes"){
-						$vhost_more_conf .= "	php_admin_flag allow_url_fopen on\n";
+						$php_more_conf .= "	php_admin_flag allow_url_fopen on\n";
 					}
 					if($subdomain["php_post_max_size"] != ""){
-						$vhost_more_conf .= "	php_admin_value post_max_size ".$subdomain["php_post_max_size"]."M\n";
+						$php_more_conf .= "	php_admin_value post_max_size ".$subdomain["php_post_max_size"]."M\n";
 					}
 					if($subdomain["php_upload_max_filesize"] != ""){
-						$vhost_more_conf .= "	php_admin_value upload_max_filesize ".$subdomain["php_upload_max_filesize"]."M\n";
+						$php_more_conf .= "	php_admin_value upload_max_filesize ".$subdomain["php_upload_max_filesize"]."M\n";
 					}
 					
 					if($subdomain["use_shared_ssl"] == "yes" && $conf_use_shared_ssl == "yes"){
@@ -833,8 +849,9 @@ $vhost_file .= "
 					if($domain_sbox_protect == "no" && $subdomain["sbox_protect"] == "no"){
 						$cgi_directive = "ScriptAlias /cgi-bin $web_path/$domain_to_get/subdomains/$web_subname/cgi-bin";
 					}else{
-						$cgi_directive = "RewriteEngine on
-	RewriteRule ^/cgi-bin/(.*) /cgi-bin/sbox/$1 [PT]";
+						$cgi_directive = "";
+//						$cgi_directive = "RewriteEngine on
+//	RewriteRule ^/cgi-bin/(.*) /cgi-bin/sbox/$1 [PT]";
 					}
 					$gen_iterations = sizeof($iteration_table);
 					for ($k = 0; $k < $gen_iterations; $k++){
@@ -854,15 +871,18 @@ $vhost_file .= "
 							$vhost_file .= "	SSLEngine on\n";
 							$vhost_file .= "	SSLCertificateFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.cert\n";
 							$vhost_file .= "	SSLCertificateKeyFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.key\n";
-		                                        if (file_exists("$ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca")) {
-                		                                $vhost_file .= "        SSLCertificateChainFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca\n";
-                                		        }
+							if (file_exists("$ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca")) {
+								$vhost_file .= "	SSLCertificateChainFile $ssl_cert_folder_path/".$web_subname.".".$domain_to_get.".cert.ca\n";
+							}
 							break;
 						case "shared_ssl":
 							$vhost_file .= "<VirtualHost ".$ip_to_write.":443>\n";
 							$vhost_file .= "	SSLEngine on\n";
 							$vhost_file .= "	SSLCertificateFile ".$conf_generated_file_path."/ssl/new.cert.cert\n";
 							$vhost_file .= "	SSLCertificateKeyFile ".$conf_generated_file_path."/ssl/new.cert.key\n";
+							if (file_exists($conf_generated_file_path."/ssl/new.cert.ca")) {
+								$vhost_file .= "	SSLCertificateChainFile ".$conf_generated_file_path."/ssl/new.cert.ca\n";
+							}
 							break;
 						}
 						$vhost_file .= "	ServerName $web_subname.$web_name
@@ -876,19 +896,39 @@ $vhost_file .= "
 		Allow from all
 	</Directory>\n";
 						}else{
-							$document_root = "$web_path/$domain_to_get/subdomains/$web_subname/html";
+							if($webadmin["shared_hosting_security"] == 'sbox_aufs' || ($webadmin["shared_hosting_security"] == 'mod_php' && $subdomain["shared_hosting_security"] == 'sbox_aufs')){
+								$document_root = "$web_path/$domain_to_get/subdomains.aufs/$web_subname/html";
+							}else{
+								$document_root = "$web_path/$domain_to_get/subdomains/$web_subname/html";
+							}
+
 							$vhost_file .= "	DocumentRoot $document_root
 	<Directory $document_root>
 		Allow from all
-	</Directory>
-$vhost_more_conf	php_admin_value safe_mode $safe_mode_value
+	</Directory>\n";
+							if($webadmin["shared_hosting_security"] == 'mod_php' && $shared_hosting_subdomain_security == 'mod_php'){
+								$vhost_file .= $vhost_more_conf.$php_more_conf."	php_admin_value safe_mode $safe_mode_value
 	php_admin_value sendmail_from phpmailfunction$web_subname@$web_name
 	php_admin_value sendmail_path \"/usr/sbin/sendmail -t -i -f phpmailfunction$web_subname@$domain_to_get\"
 	php_value session.save_path $web_path/$domain_to_get/subdomains/$web_subname/tmp
 	<Location />
 		php_admin_value open_basedir \"$web_path:$conf_php_library_path:$conf_php_additional_library_path:\"
 	</Location>
-	$cgi_directive\n".get_defaultCharsetDirective($subdomain["add_default_charset"]);
+	$cgi_directive\n";
+							}else{
+								$vhost_file .= "$vhost_more_conf	ScriptAlias /cgi-bin /usr/lib/cgi-bin
+	php_admin_flag engine off
+	AddHandler php-cgi-wrapper .php
+	Action php-cgi-wrapper /cgi-bin/sbox
+	AddHandler python-cgi-wrapper .py
+	Action python-cgi-wrapper /cgi-bin/sbox
+	AddHandler ruby-cgi-wrapper .rb
+	Action ruby-cgi-wrapper /cgi-bin/sbox
+	AddHandler ruby-cgi-wrapper .pl
+	Action ruby-cgi-wrapper /cgi-bin/sbox
+	Options +ExecCGI\n";
+							}
+							$vhost_file .= get_defaultCharsetDirective($subdomain["add_default_charset"]);
 						}
 						$vhost_file .= "	ErrorLog $web_path/$web_name/subdomains/$web_subname/logs/error.log
 	LogSQLTransferLogTable $log_tablename\$xfer
@@ -905,7 +945,8 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 </VirtualHost>
 
 ";
-						$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
+						$logrotate_file_chk[] = "$web_path/$web_name/subdomains/$web_subname/logs/error.log";
+						//$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
 						$num_generated_vhosts += $num_rows2;
 					}
 				}
@@ -918,6 +959,7 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 	if( $filep == NULL){
 		die("Cannot open $conf_generated_file_path/$conf_apache_vhost_path file for writting");
 	}
+	fwrite($filep,$vhost_file_start);
 	fwrite($filep,$vhost_file_listen);
 	fwrite($filep,$vhost_file);
 	fclose($filep);
@@ -945,26 +987,41 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 	}
 	$console .= "vhost_check_ssl_cert script written !<br>";
 
+	// Writing $aufs_list list
+	$filep = fopen("$conf_generated_file_path/aufs_list","w+");
+	if( $filep == NULL){
+		echo("Cannot open $conf_generated_file_path/aufs_lis file for writting");
+	}else{
+		fwrite($filep,$aufs_list);
+		fclose($filep);
+	}
+	$console .= "aufs_list written !<br>";
+
 	// Writing the logrotate configuration file
 	if($logrotate_file != ""){
-			$fname = "";
-			if( file_exists("/etc/dtc/logrotate.template") ){
-				$fname = "/etc/dtc/logrotate.template";
-			}else if( file_exists("/usr/local/etc/dtc/logrotate.template") ){
-				$fname = "/usr/local/etc/dtc/logrotate.template";
-			}
-			if($fname != ""){
-				$fp = fopen($fname,"r");
-				if($fp != NULL){
-					$logrotate_template = fread($fp,filesize($fname));
-					fclose($fp);
-				}else{
-					$logrotate_template = "";
-				}
+		$fname = "";
+		if( file_exists("/etc/dtc/logrotate.template") ){
+			$fname = "/etc/dtc/logrotate.template";
+		}else if( file_exists("/usr/local/etc/dtc/logrotate.template") ){
+			$fname = "/usr/local/etc/dtc/logrotate.template";
+		}
+		if($fname != ""){
+			$fp = fopen($fname,"r");
+			if($fp != NULL){
+				$logrotate_template = fread($fp,filesize($fname));
+				fclose($fp);
 			}else{
-					$logrotate_template = "";
+				$logrotate_template = "";
 			}
-			$logrotate_file .= " {
+		}else{
+			$logrotate_template = "";
+		}
+		$logrotate_file_checked = array_unique($logrotate_file_chk);
+		foreach($logrotate_file_checked as $logrotate_entry){ 
+			if(!empty($logrotate_entry)) 
+				$logrotate_file .= $logrotate_entry." ";
+		}
+		$logrotate_file .= " {
 $logrotate_template
 
 	sharedscripts
