@@ -147,8 +147,37 @@ The administrator decided that the issue is:
 	}
 }
 
+function getCustomerInfoFromLogin($login){
+	global $pro_mysql_admin_table;
+	global $pro_mysql_client_table;
+	$q = "SELECT id_client FROM $pro_mysql_admin_table WHERE adm_login='$login'";
+	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error()); 
+	$n = mysql_num_rows($r);
+	if($n != 1){
+		return _("No login by that name in the database.");
+	}
+	$a = mysql_fetch_array($r);
+	$cid = $a["id_client"];
+	$q = "SELECT is_company,company_name,familyname,christname FROM $pro_mysql_client_table WHERE id='$cid';";
+	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n != 1){
+		return _("No client by that id in the database.");
+	}
+	$a = mysql_fetch_array($r);
+	if($a["is_company"] == "yes"){
+		$out = $a["company_name"].", ";
+	}else{
+		$out = "";
+	}
+	$out .= $a["familyname"].", ";
+	$out .= $a["christname"];
+	return $out;
+}
+
 function drawNewAdminForm(){
 	global $conf_site_root_host_path;
+	global $conf_session_expir_minute;
 	global $lang;
 
 	global $pro_mysql_admin_table;
@@ -164,9 +193,17 @@ function drawNewAdminForm(){
 	global $pro_mysql_tik_cats_table;
 	global $pro_mysql_dedicated_table;
 
+	global $pro_mysql_vps_ip_table;
+	global $pro_mysql_dedicated_ips_table;
+	global $pro_mysql_dedicated_table;
+	global $pro_mysql_ssl_ips_table;
+	global $pro_mysql_subdomain_table;
+
 	global $secpayconf_currency_letters;
 	global $secpayconf_use_maxmind;
 
+	global $adm_random_pass;
+
 	get_secpay_conf();
 
 	$out = "";
@@ -176,7 +213,7 @@ function drawNewAdminForm(){
 		$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 1){
-			return _("Cannot find ticket!");
+			return _("Cannot find ticket.");
 		}
 		$a = mysql_fetch_array($r);
 		$out .= _("Subject: ") .htmlspecialchars(stripslashes($a["subject"]))."<br>";
@@ -185,15 +222,15 @@ function drawNewAdminForm(){
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 		$n2 = mysql_num_rows($r2);
 		if($n2 != 1){
-			$tmp = _("Type not found!");
+			$tmp = _("Type not found.");
 		}else{
 			$a2 = mysql_fetch_array($r2);
 			$tmp = $a2["catdescript"]."<br>";
 		}
-		$out .= _("Type:") .$tmp;
-		$out .= _("First query date: ") .$a["date"]." ".$a["time"]."<br>";
-		$out .= _("Server hostname related: ") .$a["server_hostname"]."<br>";
-		$out .= _("Admin login: ") .$a["adm_login"]."<br><br>";
+		$out .= _("Type:") .$tmp. " <br>";
+		$out .= _("First Query Date: ") .$a["date"]." ".$a["time"]."<br>";
+		$out .= _("Related Server Hostname: ") .$a["server_hostname"]."<br>";
+		$out .= _("Admin Login: ") .$a["adm_login"]."<br><br>";
 		
 		$out .= "<table cellspacing=\"0\" cellpadding=\"4\" border=\"0\">";
 		$next_tikq = $_REQUEST["tik_id"];
@@ -203,7 +240,7 @@ function drawNewAdminForm(){
 			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$n = mysql_num_rows($r);
 			if($n != 1){
-				$out .= _("Cannot find ticket!");
+				$out .= _("Cannot find ticket.");
 				break;
 			}
 			$a = mysql_fetch_array($r);
@@ -215,7 +252,7 @@ function drawNewAdminForm(){
 				$bg = " bgcolor=\"#FFFFAA\" ";
 			}
 			if($a["admin_or_user"] == "admin"){
-                        	$replied_by = "<br>"._("Replied by:")." ".$a["admin_name"];
+                        	$replied_by = "<br>"._("Replied to By:")." ".$a["admin_name"];
 			}else{
 				$replied_by = "";
 			}
@@ -239,22 +276,22 @@ function drawNewAdminForm(){
 		<input type=\"hidden\" name=\"last_tik_id\" value=\"$last_tik\">
 		<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
  <div class=\"input_btn_left\"></div>
- <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"answer\" value=\"". _("Send reply") ."\"></div>
+ <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"answer\" value=\"". _("Send Reply") ."\"></div>
  <div class=\"input_btn_right\"></div>
 </div>
 		<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
  <div class=\"input_btn_left\"></div>
- <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"answer_close\" value=\"". _("Send reply and close ticket") ."\"></div>
+ <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"answer_close\" value=\"". _("Send Reply and Close Ticket") ."\"></div>
  <div class=\"input_btn_right\"></div>
 </div>
 		<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
  <div class=\"input_btn_left\"></div>
- <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"close\" value=\"". _("Close without reply") ."\"></div>
+ <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"close\" value=\"". _("Close Without Reply") ."\"></div>
  <div class=\"input_btn_right\"></div>
 </div>
 		<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
  <div class=\"input_btn_left\"></div>
- <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"delete_thread\" value=\"". _("Delete thread silently") ."\"></div>
+ <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"delete_thread\" value=\"". _("Delete Thread Silently") ."\"></div>
  <div class=\"input_btn_right\"></div>
 </div>
 		</form>";
@@ -284,7 +321,7 @@ function drawNewAdminForm(){
 			}
 			$admin = mysql_fetch_array($r);
 			if($admin["id_client"] == "0"){
-				return _("The virtual administrator for which you are trying to manage a support ticket has no client file. Go in the Customer management screen and create a client file for this administrator.");
+				return _("The virtual administrator for which you are trying to manage a support ticket has no client file. Create a client file in the Customer Management screen for this administrator.");
 			}
 			$q = "SELECT * FROM $pro_mysql_client_table WHERE id='".$admin["id_client"]."';";
 			$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
@@ -352,7 +389,7 @@ dtcFromOkDraw()."
 ";
 
 	if($secpayconf_use_maxmind == "yes"){
-		$maxmindsays_th = "<td>" . _("MaxMind says") . "</td>";
+		$maxmindsays_th = "<td class=\"dtcDatagrid_table_titles\">" . _("MaxMind says") . "</td>";
 	}else{
 		$maxmindsays_th = "";
 	}
@@ -362,54 +399,90 @@ dtcFromOkDraw()."
 	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n < 1){
-		$waiting_new_users .= "<b>". _("No user waiting!") ."</b>";
+		$waiting_new_users .= "<b>". _("No new user requests waiting.") ."</b>";
 	}else{
-		$waiting_new_users .= "<table width=\"100%\"border=\"1\">
-<tr><td>". _("Name") ."</td><td>". _("Login") ."</td><td>". _("Domain name / VPS server hostname") ."</td><td>". _("Product") ."</td><td>". _("Date") . "</td><td>". _("Bank validated") ."</td>$maxmindsays_th<td>". _("Action") ."</td></tr>";
+		$waiting_new_users .= "<table width=\"100%\" border=\"0\" cellpadding=\"0\" cellspacing=\"1\">
+<tr><td class=\"dtcDatagrid_table_titles\">". _("Name") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Login") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Domain Name / VPS Server Hostname") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Product") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Date") . "</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Bank Validated") ."</td>$maxmindsays_th<td class=\"dtcDatagrid_table_titles\">". _("Action") ."</td></tr>";
 		for($i=0;$i<$n;$i++){
+			if($i % 2){
+				$td = "td  class=\"dtcDatagrid_table_flds\"";
+			}else{
+				$td = "td  class=\"dtcDatagrid_table_flds_alt\"";
+			}
 			$a = mysql_fetch_array($r);
-			$waiting_new_users .= "<tr><td style=\"white-space:nowrap\"><u>".htmlspecialchars($a["comp_name"]).":</u><br>";
+			$waiting_new_users .= "<tr><$td style=\"white-space:nowrap\"><u>".htmlspecialchars($a["comp_name"]).":</u><br>";
 			$waiting_new_users .= htmlspecialchars($a["family_name"]).", ".htmlspecialchars($a["first_name"])."</td>";
-			$waiting_new_users .= "<td>".$a["reqadm_login"]."</td>";
+			$waiting_new_users .= "<$td>".$a["reqadm_login"]."</td>";
 			$prod_id = $a["product_id"];
 			$q2 = "SELECT * FROM $pro_mysql_product_table WHERE id='$prod_id';";
 			$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
 			if($n2 != 1){
-				$dom_name = _("Cannot find product in db!");
-				$prod_name = _("Cannot find product in db!");
+				$dom_name = _("Cannot find product in database.");
+				$prod_name = _("Cannot find product in database.");
+				$prod_price = _("Cannot find product in database.");
 			}else{
 				$a2 = mysql_fetch_array($r2);
 				$prod_name = $a2["name"];
+				$prod_price = $a2["price_dollar"];
 				if($a2["heb_type"] == "vps"){
 					$dom_name = $a["vps_location"];
 				}else{
 					$dom_name = $a["domain_name"];
 				}
 			}
-			$waiting_new_users .= "<td>$dom_name</td><td>$prod_name</td>";
-			$waiting_new_users .= "<td>".$a["date"]." ".$a["time"]."<br>".calculateAge($a["date"],$a["time"])."</td>";
+			$waiting_new_users .= "<$td>$dom_name</td><$td>$prod_name<br>$prod_price $secpayconf_currency_letters</td>";
+			$waiting_new_users .= "<$td>".$a["date"]." ".$a["time"]."<br>".calculateAge($a["date"],$a["time"])."</td>";
 			if($a["paiement_id"] == 0){
-				$waiting_new_users .= "<td>". _("No pay ID!") ."</td>";
+				$waiting_new_users .= "<$td>". _("No payment ID.") ."</td>";
 			}else{
 				$q = "SELECT * FROM $pro_mysql_pay_table WHERE id='".$a["paiement_id"]."';";
 				$r2 = mysql_query($q)or die("Cannot select $q line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 				$n2 = mysql_num_rows($r2);
 				if($n2 != 1)	echo "Numrows!=1 in $q line: ".__LINE__." file: ".__FILE__." : problems with sql tables !";
 				$a2 = mysql_fetch_array($r2);
+				$tt = $a2["paiement_total"];
+				$secpay_site = $a2["secpay_site"];
 				if($a2["valid"] == "yes"){
-					$waiting_new_users .= "<td><font color=\"green\">"._("Yes")."</font></td>";
+					$waiting_new_users .= "<$td><font color=\"green\">"._("Yes")."</font>";
 				}elseif($a2["valid"] == "pending"){
-					$waiting_new_users .= "<td><font color=\"#FF8800\">". _("Pending") .": ". $a2["pending_reason"] ."</font></td>";
+					$waiting_new_users .= "<$td><font color=\"#FF8800\">". _("Pending") .": ". $a2["pending_reason"] ."</font>";
 				}else{
-					$waiting_new_users .= "<td><font color=\"red\">"._("No")."</font></td>";
+					$waiting_new_users .= "<$td><font color=\"red\">"._("No")."</font>";
 				}
+				$waiting_new_users .= "<br>$secpay_site: $tt $secpayconf_currency_letters</td>";
 			}
 			if($secpayconf_use_maxmind == "yes"){
-				$waiting_new_users .= "<td><pre style='width: 200px; height: 100px; overflow: scroll;'>".htmlspecialchars(
-					print_r(unserialize($a["maxmind_output"]),true))."</pre></td>";
+				$maxmind = unserialize($a["maxmind_output"]);
+				if($maxmind["riskScore"] >= 20){
+					$fnt = "<font color=\"red\">";
+					$fnt2 = "</font>";
+				}else{
+					$fnt = "";
+					$fnt2 = "";
+				}
+				$waiting_new_users .= "<$td>"._("Risk score: ").$fnt.$maxmind["riskScore"].$fnt2."<br>";
+				if($maxmind["ip_isp"] == $maxmind["ip_org"]){
+					$waiting_new_users .= _("ISP: ").$maxmind["ip_isp"].", "."<br>";
+				}else{
+					$waiting_new_users .= _("ISP: ").$maxmind["ip_isp"].", ".$maxmind["ip_org"]."<br>";
+				}
+				if($maxmind["countryMatch"] != "Yes"){
+					$fnt = "<font color=\"red\">";
+					$fnt2 = "</font>";
+				}else{
+					$fnt = "";
+					$fnt2 = "";
+				}
+				$waiting_new_users .= _("Country match: ").$fnt.$maxmind["countryMatch"]." (".$maxmind["countryCode"].")".$fnt2;
+				$waiting_new_users .= "</td>";
 			}
-			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". _("Edit") ."</a><br/>
+			$waiting_new_users .= "<$td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". _("Edit") ."</a><br/>
 			<a href=\"?action=valid_waiting_user&reqadm_id=".$a["id"]."\">". _("Add") ."</a><br/>
 			<a href=\"?action=delete_waiting_user&reqadm_id=".$a["id"]."\">". _("Delete") ."</a></td>";
 			$waiting_new_users .= "</tr>";
@@ -422,15 +495,22 @@ dtcFromOkDraw()."
 	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n < 1){
-		$waiting_new_users .= "<br><b>". _("No domain waiting!") ."</b><br>";
+		$waiting_new_users .= "<br><b>". _("No Domains Waiting.") ."</b><br>";
 	}else{
-		$waiting_new_users .= "<table border=\"1\">
-	<tr><td>". _("Login") ."</td><td>". _("Domain name") ."</td><td>". _("Action") ."</td></tr>";
+		$waiting_new_users .= "<table border=\"0\" cellpadding=\"0\" cellspacing=\"1\">
+	<tr><td class=\"dtcDatagrid_table_titles\">". _("Login") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Domain Name") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Action") ."</td></tr>";
 		for($i=0;$i<$n;$i++){
+			if($i % 2){
+				$td = "td  class=\"dtcDatagrid_table_flds\"";
+			}else{
+				$td = "td  class=\"dtcDatagrid_table_flds_alt\"";
+			}
 			$a = mysql_fetch_array($r);
-			$waiting_new_users .= "<td>".$a["adm_login"]."</td>";
-			$waiting_new_users .= "<td>".$a["domain_name"]."</td>";
-			$waiting_new_users .= "<td><a href=\"?action=valid_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Add") ."</a>
+			$waiting_new_users .= "<$td>".$a["adm_login"]."</td>";
+			$waiting_new_users .= "<$td>".$a["domain_name"]."</td>";
+			$waiting_new_users .= "<$td><a href=\"?action=valid_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Add") ."</a>
 - <a href=\"?action=delete_waiting_domain_to_user&reqid=".$a["id"]."\">". _("Delete") ."</a></td></tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -441,29 +521,68 @@ dtcFromOkDraw()."
 	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n < 1){
-		$waiting_new_users .= "<b>". _("No pending renewals!") ."</b><br>";
+		$waiting_new_users .= "<b>". _("No pending renewals.") ."</b><br>";
 	}else{
-		$waiting_new_users .= "<table border=\"1\">
-<tr><td>". _("Login")."</td><td>". _("Product") ."</td><td>". _("Payment date") ."</td><td>". _("Bank validated") ."</td><td>". _("Type") ."</td><td>". _("Action") ."</td></tr>";
+		$waiting_new_users .= "<table border=\"0\" cellpadding=\"0\" cellspacing=\"1\">
+<tr><td class=\"dtcDatagrid_table_titles\">". _("Login")."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Product") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Payment Date") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Bank Validated") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Type") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Action") ."</td></tr>";
 		for($i=0;$i<$n;$i++){
-			$a = mysql_fetch_array($r);
-			$waiting_new_users .= "<tr><td>".$a["adm_login"]."</td>";
-			$q2 = "SELECT name,price_dollar,period FROM $pro_mysql_product_table WHERE id='".$a["product_id"]."';";
-			$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
-			$n2 = mysql_num_rows($r2);
-			if($n2 != 1){
-				$prod_name = _("Cannot find product!");
+			if($i % 2){
+				$td = "td  class=\"dtcDatagrid_table_flds\"";
 			}else{
-				$a2 = mysql_fetch_array($r2);
-				$prod_name = $a2["name"]." (".$a2["price_dollar"]." $secpayconf_currency_letters: ".$a2["period"].")";
+				$td = "td  class=\"dtcDatagrid_table_flds_alt\"";
 			}
-			$waiting_new_users .= "<td>$prod_name</td>";
-			$waiting_new_users .= "<td>".$a["renew_date"]." ".$a["renew_time"]."</td>";
+			$a = mysql_fetch_array($r);
+			$waiting_new_users .= "<tr><$td>".$a["adm_login"]."</td>";
+			if($a["heb_type"] == "multiple-services"){
+				$servs = explode("|",$a["services"]);
+				$n_servs = sizeof($servs);
+				$prod_name = "";
+				for($j=0;$j<$n_servs;$j++){
+					if($j>0){
+						$prod_name .= "<br>";
+					}
+					$attrs = explode(":",$servs[$j]);
+					switch($attrs[0]){
+					case "vps":
+						$ind = 3;
+						break;
+					case "server":
+						$ind = 2;
+						break;
+					}
+					$q2 = "SELECT name,price_dollar,period FROM $pro_mysql_product_table WHERE id='".$attrs[$ind]."';";
+					$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
+					$n2 = mysql_num_rows($r2);
+					if($n2 != 1){
+						$prod_name .= _("Cannot find product.");
+					}else{
+						$a2 = mysql_fetch_array($r2);
+						$prod_name .= $a2["name"]." (".$a2["price_dollar"]." $secpayconf_currency_letters: ".$a2["period"].")";
+					}
+				}
+			}else{
+				$q2 = "SELECT name,price_dollar,period FROM $pro_mysql_product_table WHERE id='".$a["product_id"]."';";
+				$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
+				$n2 = mysql_num_rows($r2);
+				if($n2 != 1){
+					$prod_name = _("Cannot find product.");
+				}else{
+					$a2 = mysql_fetch_array($r2);
+					$prod_name = $a2["name"]." (".$a2["price_dollar"]." $secpayconf_currency_letters: ".$a2["period"].")";
+				}
+			}
+			$waiting_new_users .= "<$td>$prod_name</td>";
+			$waiting_new_users .= "<$td>".$a["renew_date"]." ".$a["renew_time"]."</td>";
 			$q2 = "SELECT * FROM $pro_mysql_pay_table WHERE id='".$a["pay_id"]."';";
 			$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
 			if($n2 != 1){
-				$bank = _("Cannot find payment!");
+				$bank = _("Cannot find payment.");
 			}else{
 				$a2 = mysql_fetch_array($r2);
 				switch($a2["valid"]){
@@ -479,13 +598,13 @@ dtcFromOkDraw()."
 					break;
 				}
 			}
-			$waiting_new_users .= "<td>$bank</td>";
+			$waiting_new_users .= "<$td>$bank</td>";
 			switch($a["heb_type"]){
 			case "vps":
 				$q2 = "SELECT * FROM $pro_mysql_vps_table WHERE id='".$a["renew_id"]."'";
 				$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 				if($n2 != 1){
-					$heb_type = _("VPS: Cannot find VPS in db!");
+					$heb_type = _("VPS: Cannot find VPS in database.");
 				}else{
 					$a2 = mysql_fetch_array($r2);
 					$heb_type = "VPS: ".$a2["vps_xen_name"]."@".$a2["vps_server_hostname"];
@@ -511,19 +630,38 @@ dtcFromOkDraw()."
 				$q2 = "SELECT * FROM $pro_mysql_dedicated_table WHERE id='".$a["renew_id"]."'";
 				$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 				if($n2 != 1){
-					$tmp = _("Cannot find server in db!");
+					$tmp = _("Cannot find server in database.");
 				}else{
 					$a2 = mysql_fetch_array($r2);
 					$tmp = $a2["server_hostname"];
 				}
-				$heb_type = _("Server:") .$tmp;
+				$heb_type = _("Server:") ." ".$tmp;
+				break;
+			case "multiple-services":
+				$servs = explode("|",$a["services"]);
+				$n_servs = sizeof($servs);
+				$heb_type = "";
+				for($j=0;$j<$n_servs;$j++){
+					if($j>0){
+						$heb_type .= "<br>";
+					}
+					$attrs = explode(":",$servs[$j]);
+					switch($attrs[0]){
+					case "vps":
+						$heb_type .= _("VPS: ").$attrs[2]."@".$attrs[1];
+						break;
+					case "server":
+						$heb_type .= _("Server:")." ".$attrs[1];
+						break;
+					}
+				}
 				break;
 			default:
 				echo "Renew type ".$a["heb_type"]." not implemented line ".__LINE__." file ".__FILE__;
 				break;
 			}
-			$waiting_new_users .= "<td>$heb_type</td>";
-			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a href=\"?action=validate_renewal&id=".$a["id"]."\">". _("Validate") ."</a> <a href=\"?action=delete_renewal&id=".$a["id"]."\">". _("Del") ."</a></td>";
+			$waiting_new_users .= "<$td>$heb_type</td>";
+			$waiting_new_users .= "<$td style=\"white-space:nowrap\"><a href=\"?action=validate_renewal&id=".$a["id"]."\">". _("Validate") ."</a> <a href=\"?action=delete_renewal&id=".$a["id"]."\">". _("Del") ."</a></td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -533,11 +671,21 @@ dtcFromOkDraw()."
 	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n < 1){
-		$waiting_new_users .= "<b>". _("No pending support tickets!") ."</b><br>";
+		$waiting_new_users .= "<b>". _("No pending support tickets.") ."</b><br>";
 	}else{
-		$waiting_new_users .= "<table border=\"1\">
-<tr><td>". _("Login") ."</td><td>". _("Age") ."</td><td>". _("Type") ."</td><td>". _("Subject") ."</td><td>". _("Last message from"). "</td><td>" ._("Last message age"). "</td></tr>";
+		$waiting_new_users .= "<table border=\"0\" cellpadding=\"0\" cellspacing=\"1\">
+<tr><td class=\"dtcDatagrid_table_titles\">". _("Login") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Age") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Type") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Subject") ."</td>
+<td class=\"dtcDatagrid_table_titles\">". _("Last message from"). "</td>
+<td class=\"dtcDatagrid_table_titles\">" ._("Last message age"). "</td></tr>";
 		for($i=0;$i<$n;$i++){
+			if($i % 2){
+				$td = "td  class=\"dtcDatagrid_table_flds\"";
+			}else{
+				$td = "td  class=\"dtcDatagrid_table_flds_alt\"";
+			}
 			$a = mysql_fetch_array($r);
 			if( strlen($a["customer_email"]) != 0){
 				$who = $a["customer_email"];
@@ -547,18 +695,18 @@ dtcFromOkDraw()."
 			}else{
 				$who = $a["adm_login"];
 			}
-			$waiting_new_users .= "<tr><td>$who</td>";
+			$waiting_new_users .= "<tr><$td>$who</td>";
 			$q2 = "SELECT * FROM $pro_mysql_tik_cats_table WHERE id='".$a["cat_id"]."'";
 			$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
 			if($n2 != 1){
-				$cat = _("Type not found!");
+				$cat = _("Type not found.");
 			}else{
 				$a2 = mysql_fetch_array($r2);
 				$cat = $a2["catname"];
 			}
 			$age = calculateAge($a["date"],$a["time"]);
-			$waiting_new_users .= "<td style=\"white-space:nowrap;\">$age</td><td>$cat</td><td style=\"white-space:nowrap;\"><a href=\"?subaction=resolv_ticket&tik_id=".$a["id"]."\">".htmlspecialchars(stripslashes($a["subject"]))."</a></td>";
+			$waiting_new_users .= "<$td style=\"white-space:nowrap;\">$age</td><$td>$cat</td><$td style=\"white-space:nowrap;\"><a href=\"?subaction=resolv_ticket&tik_id=".$a["id"]."\">".htmlspecialchars(stripslashes($a["subject"]))."</a></td>";
 			$next_reply_id = $a["reply_id"];
 			$last_reply_text = "<font color=\"green\">". _("Admin"). "</font>";
 			$last_message_date = $a["date"];
@@ -583,26 +731,140 @@ dtcFromOkDraw()."
 					$last_guy_replied = "admin";
 				}
 				$next_reply_id = $a3["reply_id"];
-				if($loop_num >= 49){
-					echo "Warning: loop_num exeeded 50while reading ticket for $who and ID $next_reply_id, not displaying last ticket while reading ticket for $who: not displaying last ticket reply from line".__LINE__." file ".__FILE__;
+				if($loop_num >= 199){
+					echo "Warning: loop_num exeeded 200 while reading ticket for $who and ID $next_reply_id, not displaying last ticket while reading ticket for $who: not displaying last ticket reply from line".__LINE__." file ".__FILE__;
 				}
 			}
 			if($last_guy_replied == "user"){
 				$last_reply_text = "<font color=\"red\">". _("User") ."</font>";
 			}
-			$waiting_new_users .= "<td>$last_reply_text</td>";
+			$waiting_new_users .= "<$td>$last_reply_text</td>";
 			$age2 = calculateAge($last_message_date,$last_message_time);
-			$waiting_new_users .= "<td>".$age2."</td>";
+			$waiting_new_users .= "<$td>".$age2."</td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
 	}
-	return "<table>
+	if(isset($_REQUEST["search_subject"])){
+		$ss = $_REQUEST["search_subject"];
+	}else{
+		$ss = "";
+	}
+	$search = "<h3>". _("Search engine") ."</h3>
+<form name=\"search_me\" action=\"?\" method=\"get\">
+<input type=\"hidden\" name=\"search_query\" value=\"do\">
+".dtcFormTableAttrs().
+dtcFormLineDraw("","
+
+<table border=\"0\"><tr>
+<td><input class=\"dtcDatagrid_input_color\" size=\"60\" type=\"text\" name=\"search_subject\" value=\"$ss\"></td>
+<td>".submitButtonStart()._("Search").submitButtonEnd(),0)."</td></tr></table>
+
+
+</form>
+</table>
+";
+
+	if( isset($_REQUEST["search_query"])){
+		if(isset($adm_random_pass)){
+			$rand = $adm_random_pass;
+		}else{
+			$rand = getRandomValue();
+			$adm_random_pass = $rand;
+			$expirationTIME = mktime() + (60 * $conf_session_expir_minute);
+			$q = "UPDATE $pro_mysql_tik_admins_table SET pass_next_req='$rand', pass_expire='$expirationTIME' WHERE pseudo='".$_SERVER["PHP_AUTH_USER"]."';";
+			$r = mysql_query($q)or die("Cannot execute query \"$q\" !");
+		}
+
+		$sr = "<h3>"._("Search result")."</h3><br>";
+		// Search IPs
+		if( isIP($_REQUEST["search_subject"]) ){
+			// Search VPS IPs
+			$q = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_addr='".$_REQUEST["search_subject"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			for($i=0;$i<$n;$i++){
+				$a = mysql_fetch_array($r);
+				$q2 = "SELECT * FROM $pro_mysql_vps_table WHERE vps_server_hostname='".$a["vps_server_hostname"]."' AND vps_xen_name='".$a["vps_xen_name"]."';";
+				$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+				$n2 = mysql_num_rows($r2);
+				if($n2 == 1){
+					$a2 = mysql_fetch_array($r2);
+					$owner = $a2["owner"];
+					$sr .= _("Login:")." ".$owner."<br>";
+					$sr .= _("Customer:")." ".getCustomerInfoFromLogin($owner)."<br>";
+					$sr .= "<a href=\"?adm_login=$owner&adm_pass=$adm_random_pass&addrlink=vps:".$a["vps_server_hostname"].":".$a["vps_xen_name"]."\">".$a["vps_xen_name"].":".$a["vps_server_hostname"]."</a><br><br>";
+				}
+			}
+			// Search Dedicated IPs
+			$q = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_addr='".$_REQUEST["search_subject"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			for($i=0;$i<$n;$i++){
+				$a = mysql_fetch_array($r);
+				$q2 = "SELECT * FROM $pro_mysql_dedicated_table WHERE server_hostname='".$a["dedicated_server_hostname"]."';";
+				$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+				$n2 = mysql_num_rows($r2);
+				if($n2 == 1){
+					$a2 = mysql_fetch_array($r2);
+					$owner = $a2["owner"];
+					$sr .= _("Login:")." ".$owner."<br>";
+					$sr .= _("Customer:")." ".getCustomerInfoFromLogin($owner)."<br>";
+					$sr .= "<a href=\"?adm_login=$owner&adm_pass=$adm_random_pass&addrlink=server:".$a["dedicated_server_hostname"]."\">".$a["dedicated_server_hostname"]."</a><br><br>";
+				}
+			}
+			// Search SSL IPs
+			$q = "SELECT * FROM $pro_mysql_ssl_ips_table WHERE ip_addr='".$_REQUEST["search_subject"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			for($i=0;$i<$n;$i++){
+				$a = mysql_fetch_array($r);
+				$q2 = "SELECT * FROM $pro_mysql_subdomain_table WHERE ssl_ip='".$_REQUEST["search_subject"]."';";
+				$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+				$n2 = mysql_num_rows($r2);
+				if($n2 == 1){
+					$a2 = mysql_fetch_array($r2);
+					$owner = $a["adm_login"];
+					$sr .= _("Login:")." ".$owner."<br>";
+					$sr .= _("Customer:")." ".getCustomerInfoFromLogin($owner)."<br>";
+					$sr .= "<a href=\"?adm_login=$owner&adm_pass=$adm_random_pass&addrlink=".$a2["domain_name"]."/subdomains&subaction=subdomain_editor_edit_item&item=".$a2["id"]."\">".$a2["subdomain_name"].".".$a2["domain_name"]."</a><br><br>";
+				}
+			}
+		// Search on emails
+		}elseif( isValidEmail($_REQUEST["search_subject"]) ){
+			$q = "SELECT * FROM $pro_mysql_client_table WHERE email='".$_REQUEST["search_subject"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			for($i=0;$i<$n;$i++){
+				$a = mysql_fetch_array($r);
+				$q2 = "SELECT * FROM $pro_mysql_admin_table WHERE id_client='".$a["id"]."';";
+				$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+				$n2 = mysql_num_rows($r2);
+				if($n2 == 1){
+					$a2 = mysql_fetch_array($r2);
+					$owner = $a2["adm_login"];
+					$sr .= _("Login:")." ".$owner."<br>";
+					$sr .= _("Customer:")." ".getCustomerInfoFromLogin($owner)."<br>";
+					$sr .= "<a href=\"?adm_login=$owner&adm_pass=$adm_random_pass\">".$owner."</a><br><br>";
+				}
+			}
+		}
+		return "<table>
 <tr>
+	<td valign=\"top\">".$search."</td>
+	</tr><tr>
+	<td valign=\"top\">".$sr."</td></tr></table>";
+	}else{
+		return "<table>
+<tr>
+	<td valign=\"top\">".$search."</td>
+	</tr><tr>
 	<td valign=\"top\">".$waiting_new_users."</td>
 	</tr><tr>
 	<td valign=\"top\">".$add_a_user."</td>
 </tr></table>";
+	}
+
 }
 
 function skinConsole(){
