@@ -231,7 +231,11 @@ function dtcDatagrid($dsc){
 					}else{
 						$happen = "";
 					}
-					$vals .= "'".$_REQUEST[ $keys[$i] ].$happen."'";
+					if( $dsc["cols"][ $keys[$i] ]["type"] == "password" && $dsc["cols"][ $keys[$i] ]["encrypt"] == "yes"){
+						$vals .= "SHA1('".$_REQUEST[ $keys[$i] ].$happen."')";
+					}else{
+						$vals .= "'".$_REQUEST[ $keys[$i] ].$happen."'";
+					}
 					$added_one = "yes";
 					break;
 				case "checkbox":
@@ -248,6 +252,9 @@ function dtcDatagrid($dsc){
 					$vals .= "'".$dsc["cols"][ $keys[$i] ]["values"][$index_val]."'";
 					$added_one = "yes";
 					break;
+				case "custom_fld":
+					//
+					break;
 				default:
 					break;
 				}
@@ -295,7 +302,11 @@ function dtcDatagrid($dsc){
 					if($added_one == "yes"){
                                                 $vals .= ", ";
                                         }
-                                        $vals .= " ".$keys[$i]."='".$_REQUEST[ $keys[$i] ]."' ";
+					if( $dsc["cols"][ $keys[$i] ]["encrypt"] == "yes"){
+	                                        $vals .= " ".$keys[$i]."=SHA1('".$_REQUEST[ $keys[$i] ]."') ";
+					}else{
+	                                        $vals .= " ".$keys[$i]."='".$_REQUEST[ $keys[$i] ]."' ";
+					}
                                         $added_one = "yes";
 					// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
 					if(isset($dsc["cols"][ $keys[$i] ]["cryptfield"])){
@@ -305,6 +316,18 @@ function dtcDatagrid($dsc){
 						$vals .= " ".$dsc["cols"][ $keys[$i] ]["cryptfield"]."='".crypt($_REQUEST[ $keys[$i] ], dtc_makesalt())."' ";
 					}
                                         break;
+				case "custom_fld":
+					if($added_one == "yes"){
+						$vals .= ", ";
+					}
+					$arr_request = array();
+					foreach ($_REQUEST[ $keys[$i] ] as $req_field => $req_value){
+						$arr_request[] = $req_field.":".$req_value;
+					}
+					$txt_request = join("|",$arr_request);
+					$vals .= " ".$keys[$i]."='".$txt_request."' ";
+					$added_one = "yes";
+					break;
 				default:
 					if($added_one == "yes"){
 						$vals .= ", ";
@@ -367,6 +390,9 @@ function dtcDatagrid($dsc){
 			}else{
 				$jshelp = "";
 			}
+			if (!isset($dsc["cols"][ $keys[$i] ]["legend"])){
+				$dsc["cols"][ $keys[$i] ]["legend"] = "";
+			}
 			$out .= "<td $jshelp class=\"dtcDatagrid_table_titles\">".$dsc["cols"][ $keys[$i] ]["legend"]."</td>";
 		}
 	}
@@ -497,7 +523,11 @@ function dtcDatagrid($dsc){
 			}else{
 				$the_type = $the_fld["type"];
 				if($the_type != "hyperlink"){
-					$db_value = $a[ $the_name ];
+					if (isset($a[ $the_name ])){
+						$db_value = $a[ $the_name ];
+					}else{
+						$db_value = "";
+					}
 				}
 			}
 			switch($the_type){
@@ -613,6 +643,79 @@ function dtcDatagrid($dsc){
 					$out .= $id_hidden;
 				}
 				break;
+			case "custom_fld":
+				$out .= "<td class=\"$tdclass\">";
+				
+				// Manage the output of custom fields.
+				$customer_custom_fields = array();
+				$explo_row = explode("|", htmlspecialchars(stripcslashes($db_value)));
+				$n_custf = sizeof($explo_row);
+				for($ix=0;$ix<$n_custf;$ix++){
+					$one_fld = $explo_row[$ix];
+					$pos_data = strpos($one_fld,":");
+					if($pos_data === false){
+						continue;
+					}
+					$varname = substr($one_fld,0,$pos_data);
+					$value = substr($one_fld,$pos_data+1);
+					$customer_custom_fields[ $varname ] = $value;
+				}
+				$qa = "SELECT ".$the_fld["main_table"].".* FROM ".$the_fld["main_table"]." INNER JOIN ".$the_fld["second_table"]." ON ".$the_fld["main_join_clause"]." INNER JOIN ".$the_fld["third_table"]." ON ".$the_fld["second_join_clause"]." WHERE ".$the_fld["where_field"]." = $id ORDER BY ".$the_fld["order_field"].";";
+				//echo " | ".$qa." ";
+				$ra = mysql_query($qa)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+				$na = mysql_num_rows($ra);
+				$init_alt = 1;
+
+				for($iz=0;$iz<$na;$iz++){
+					$aa = mysql_fetch_array($ra);
+					if(isset($customer_custom_fields[ $aa["varname"] ])){
+						$val = $customer_custom_fields[ $aa["varname"] ];
+					}else{
+						$val = "";
+					}
+					switch($aa["widgettype"]){
+					case "radio":
+						$explo_popup = explode("|",$aa["widgetvalues"]);
+						$explo_popup2 = explode("|",$aa["widgetdisplay"]);
+						$n_val = sizeof($explo_popup);
+						$widget = "";
+						for($jz=0;$jz<$n_val;$jz++){
+							if($val == $the_name[$explo_popup[$jz]]){
+								$sel = " checked ";
+							}else{
+								$sel = " ";
+							}
+							$widget .= "<input type=\"radio\" name=\"".$the_name."[".$aa["varname"]."]\" value=\"".$explo_popup[$jz]."\" $sel > ".$explo_popup2[$jz];
+						}
+						break;
+					case "popup":
+						$explo_popup = explode("|",$aa["widgetvalues"]);
+						$explo_popup2 = explode("|",$aa["widgetdisplay"]);
+						$n_val = sizeof($explo_popup);
+						$widget = "<select name=\"".$the_name."[".$aa["varname"]."]\">";
+						for($jz=0;$jz<$n_val;$jz++){
+							if($val == $the_name[$explo_popup[$jz]]){
+								$sel = " selected ";
+							}else{
+								$sel = " ";
+							}
+							$widget .= "<option value=\"".$explo_popup[$jz]."\" $sel >".$explo_popup2[$jz]."</option>";
+						}
+						$widget .= "</select>";
+						break;
+					case "textarea":
+						$widget = "<textarea name=\"".$the_name."[".$aa["varname"]."]\">".htmlspecialchars($val)."</textarea>";
+						break;
+					case "text":
+					default:
+						$widget = "<input size=\"40\" type=\"text\" name=\"".$the_name."[".$aa["varname"]."]\" value=\"".htmlspecialchars($val)."\">";
+						break;
+					}
+					$out .= $aa["question"].": ".$widget; //,$init_alt);
+				}
+
+				$out .= "</td>";
+				break;
 			}
 		}
 		$out .= "<td class=\"$tdclass\">".dtcApplyButton()."</form></td>";
@@ -914,6 +1017,12 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "page_url":
+					if( !isPageURL($_REQUEST[ $keys[$i] ]) ){
+						$commit_flag = "no";
+						$commit_err .= $keys[$i]._(": not a page URL")."<br>";
+					}
+					break;
 				case "ip_addr":
 					if( !isIP($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -976,6 +1085,10 @@ function dtcListItemsEdit($dsc){
 							$commit_err .= $keys[$i].": not a correct password format<br>";
 						}
 					}
+					if( FALSE != check_password($_REQUEST[ $keys[$i] ])){
+						$commit_flag = "no";
+						$commit_err .= $keys[$i].": "._("This password is one of the 500 most used passwords on the internet. Please choose a stronger one.");
+					}
 					break;
 				case "email":
 					if( !isValidEmail($_REQUEST[ $keys[$i] ]) ){
@@ -1142,7 +1255,7 @@ function dtcListItemsEdit($dsc){
 				$out .= "<font color=\"red\">Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_error()."</font>";
 			}
 		}else{
-			$out .= "<font color=\"red\">Could not commit the changes because of an error in field format: <br>$commit_err</font><br>";
+			$out .= "<font color=\"red\">"._("Could not commit the changes because of an error in field format: ")."<br>$commit_err</font><br>";
 		}
 	}else if( isset($_REQUEST["action"]) && $_REQUEST["action"] == $dsc["action"]."_save_item" ){
 		// Todo: do the fields checkings
@@ -1164,7 +1277,7 @@ function dtcListItemsEdit($dsc){
 				}
 				if($is_one_of_them == "no"){
 					$commit_flag = "no";
-					$commit_err = "the variable ".$keys[$i]." is not one of the allowed values<br>";
+					$commit_err = "the variable ".$keys[$i]._(" is not one of the allowed values")."<br>";
 				}
 				break;
 			default:
@@ -1178,7 +1291,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a subdomain<br>";
+							$commit_err .= $keys[$i]._(": not a subdomain")."<br>";
 						}
 					}
 					break;
@@ -1193,7 +1306,7 @@ function dtcListItemsEdit($dsc){
 					for($g=0;$g<$number_of_ip;$g++){
 						if( !isIP($mylist_of_ip[$g]) ){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": invalid IP list<br>";
+							$commit_err .= $keys[$i]._(": invalid IP list")."<br>";
 						}
 					}
 					break;
@@ -1203,7 +1316,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a subdomain or IP addresse<br>";
+							$commit_err .= $keys[$i]._(": not a subdomain or IP addresse")."<br>";
 						}
 					}
 					break;
@@ -1216,18 +1329,24 @@ function dtcListItemsEdit($dsc){
 										|| $dsc["cols"][ $keys[$i] ]["empty_makes_default"] != "yes"
 										|| $_REQUEST[ $keys[$i] ] != "default"){
 								$commit_flag = "no";
-								$commit_err .= $keys[$i].": not an IPv6 address<br>";
+								$commit_err .= $keys[$i]._(": not an IPv6 address")."<br>";
 							}
 						}
 					}
 					break;
+				case "page_url":
+					if( !isPageURL($_REQUEST[ $keys[$i] ]) ){
+						$commit_flag = "no";
+						$commit_err .= $keys[$i]._(": not a page URL")."<br>";
+					}
+					break;
 				case "ip_addr":
 					if( !isIP($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not an IP address<br>";
+							$commit_err .= $keys[$i]._(": not an IP address")."<br>";
 						}
 					}
 					break;
@@ -1237,7 +1356,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a domain or IP addresse<br>";
+							$commit_err .= $keys[$i]._(": not a domain or IP addresse")."<br>";
 						}
 					}
 					break;
@@ -1247,7 +1366,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a correct login format.<br>";
+							$commit_err .= $keys[$i]._(": not a correct login format")."<br>";
 						}
 					}
 					break;
@@ -1257,7 +1376,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a correct login format.<br>";
+							$commit_err .= $keys[$i]._(": not a correct login format")."<br>";
 						}
 					}
 					break;
@@ -1270,7 +1389,7 @@ function dtcListItemsEdit($dsc){
 						if ( ! isValidEmail($mail_alias_array[$x]) )
 						{
 							$commit_flag = "no";
-							$commit_err .= $mail_alias_array[$x].": not a valid email format.<br>";
+							$commit_err .= $mail_alias_array[$x]._(": not a valid email format")."<br>";
 						}
 					}
 					break;
@@ -1280,9 +1399,13 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a correct password format<br>";
+							$commit_err .= $keys[$i]._(": not a correct password format")."<br>";
 						}
 					}
+					if( FALSE != check_password($_REQUEST[ $keys[$i] ]) ){
+						$commit_flag = "no";
+						$commit_err .= $keys[$i].": "._("This password is one of the 500 most used passwords on the internet. Please choose a stronger one.");
+					}
 					break;
 				case "email":
 					if( !isValidEmail($_REQUEST[ $keys[$i] ]) ){
@@ -1290,7 +1413,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a correct email format<br>";
+							$commit_err .= $keys[$i]._(": not a correct email format")."<br>";
 						}
 					}
 					break;
@@ -1300,7 +1423,7 @@ function dtcListItemsEdit($dsc){
 									|| $dsc["cols"][ $keys[$i] ]["can_be_empty"] != "yes"
 									|| $_REQUEST[ $keys[$i] ] != ""){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a correct number format<br>";
+							$commit_err .= $keys[$i]._(": not a correct number format")."<br>";
 						}
 					}
 					break;
@@ -1310,17 +1433,17 @@ function dtcListItemsEdit($dsc){
 								|| $_REQUEST[ $keys[$i] ] != ""){
 						if( !isRandomNum($_REQUEST[ $keys[$i] ]) ){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": not a correct number format<br>";
+							$commit_err .= $keys[$i]._(": not a correct number format")."<br>";
 						}
 						if($_REQUEST[ $keys[$i] ] >= 2096){
 							$commit_flag = "no";
-							$commit_err .= $keys[$i].": is greater or equal than the max value 2096<br>";
+							$commit_err .= $keys[$i]._(": is greater or equal than the max value 2096")."<br>";
 						}
 					}
 					break;
 				default:
 					$commit_flag = "no";
-					$commit_err .= $keys[$i].": unknown field checking type (".$dsc["cols"][ $keys[$i] ]["check"].").<br>";
+					$commit_err .= $keys[$i]._(": unknown field checking type")." (".$dsc["cols"][ $keys[$i] ]["check"].").<br>";
 					break;
 				}
 			}
