@@ -58,14 +58,14 @@ function drawAdminTools_Dedicated($admin,$dedicated_server_hostname){
 	$n = mysql_num_rows($r);
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
-		$out .= "<form action=\"/dtc/new_account.php\">
+		$out .= "<br><form action=\"/dtc/new_account.php\">
 		<input type=\"hidden\" name=\"action\" value=\"contract_renewal\">
 		<input type=\"hidden\" name=\"renew_type\" value=\"server\">
 		<input type=\"hidden\" name=\"product_id\" value=\"".$a["id"]."\">
 		<input type=\"hidden\" name=\"server_id\" value=\"".$dedicated["id"]."\">
 		<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
-		<input type=\"submit\" value=\"".$a["name"]." (".$a["price_dollar"]." $secpayconf_currency_letters)"."\">
-		</form>";
+		".submitButtonStart().$a["name"]." (".$a["price_dollar"]." $secpayconf_currency_letters)".submitButtonEnd()."
+		</form><br>";
 	}
 
 //	$out .= "Dedicated server content!";
