@@ -41,6 +41,7 @@ function drawEditAdmin($admin){
 	$ssh_login_flag = $info["ssh_login_flag"];
 	$ftp_login_flag = $info["ftp_login_flag"];
 	$pkg_install_flag = $info["pkg_install_flag"];
+	$shared_hosting_security = $info["shared_hosting_security"];
 
 	if($resseller_flag == "yes"){
 		$resflag_yes = " checked='checked' ";
@@ -136,6 +137,32 @@ function drawEditAdmin($admin){
 	$allow_subdomain_edit_selector = "<input type=\"radio\" name=\"allow_subdomain_edit\" value=\"yes\"$allow_subdomain_edit_yes> "._("Yes")."
 <input type=\"radio\" name=\"allow_subdomain_edit\" value=\"no\"$allow_subdomain_edit_no> "._("No");
 
+	// The shared hosting security popup
+	switch($shared_hosting_security){
+	case "mod_php":
+		$shared_hosting_security_mod_php_sel = " selected ";
+		$shared_hosting_security_sbox_copy_sel = "";
+		$shared_hosting_security_sbox_aufs_sel = "";
+		break;
+	case "sbox_copy":
+		$shared_hosting_security_mod_php_sel = "";
+		$shared_hosting_security_sbox_copy_sel = " selected ";
+		$shared_hosting_security_sbox_aufs_sel = "";
+		break;
+	case "sbox_aufs":
+		$shared_hosting_security_mod_php_sel = "";
+		$shared_hosting_security_sbox_copy_sel = "";
+		$shared_hosting_security_sbox_aufs_sel = "selected";
+		break;
+	default:
+		break;
+	}
+	$shared_hosting_security_popup = "<select name=\"shared_hosting_security\">
+	<option value=\"mod_php\"$shared_hosting_security_mod_php_sel>mod_php</option>
+	<option value=\"sbox_copy\"$shared_hosting_security_sbox_copy_sel>sbox_copy</option>
+	<option value=\"sbox_aufs\"$shared_hosting_security_sbox_aufs_sel>sbox_aufs</option>
+	</select>";
+
 	// Generate the user configuration form
 	$user_data = "
 <form name=\"admattrbfrm\" action=\"?\" methode=\"post\">
@@ -153,7 +180,7 @@ function drawEditAdmin($admin){
 	$user_data .= dtcFormLineDraw( _("Password:") ,$ctrl);
 
 	// The product popup
-	$q = "SELECT * FROM $pro_mysql_product_table WHERE (heb_type='shared' OR heb_type='ssl') AND renew_prod_id='0' ORDER BY id;";
+	$q = "SELECT * FROM $pro_mysql_product_table WHERE (heb_type='shared' OR heb_type='custom' OR heb_type='ssl') AND renew_prod_id='0' ORDER BY id;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	$prodsid = "";
@@ -169,6 +196,7 @@ function drawEditAdmin($admin){
 	}
 	$prodsid .= "</select>";
 
+
 	$user_data .= dtcFormLineDraw( _("Path:") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"changed_path\" value=\"$adm_path\">",0);
 	$user_data .= dtcFormLineDraw( _("Client ID:") ,"<input class=\"dtcDatagrid_input_color\" type=\"text\" name=\"changed_id_client\" value=\"$adm_id_client\"><a href=\"?rub=crm&id=$adm_id_client\">"._("client")."</a>");
 	$user_data .= dtcFormLineDraw( _("Disk quota (MB):") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"adm_quota\" value=\"$adm_quota\">",0);
@@ -182,16 +210,17 @@ function drawEditAdmin($admin){
 	$user_data .= dtcFormLineDraw( _("Allow addition of SSH logins:") ,$sshlog_selector,0);
 	$user_data .= dtcFormLineDraw( _("Allow addition of FTP logins:") ,$ftplog_selector);
 	$user_data .= dtcFormLineDraw( _("Restrict FTP to the html folder:") ,$restricted_ftp_path_selector,0);
-	$user_data .= dtcFormLineDraw( _("Allow addition of mailing lists and mail groups:") ,$allow_mailing_list_edit_selector);
+	$user_data .= dtcFormLineDraw( _("Allow edition of mailing lists and mail groups:") ,$allow_mailing_list_edit_selector);
 	$user_data .= dtcFormLineDraw( _("Allow edition of DNS and MX:") ,$allow_dns_and_mx_change_selector,0);
-	$user_data .= dtcFormLineDraw( _("Allow edition subdomains:") ,$allow_subdomain_edit_selector);
+	$user_data .= dtcFormLineDraw( _("Allow edition of subdomains:") ,$allow_subdomain_edit_selector);
 	$user_data .= dtcFormLineDraw( _("Allow the use of the package installer:") ,$pkg_install_selector,0);
+	$user_data .= dtcFormLineDraw( _("Shared hosting security:"),$shared_hosting_security_popup);
 	$user_data .= dtcFromOkDraw()."</table></form>";
 
 	// Generate the admin tool configuration module
 	// Deletion of domains :
 	$url = "?delete_admin_user=$adm_login&rub=$rub";
-	$confirmed_url = dtcJavascriptConfirmLink( _("Are your sure you want to delete this user? This will erase all his hosted domain names, files, and databases !!!") ,$url);
+	$confirmed_url = dtcJavascriptConfirmLink( _("Are your sure you want to delete this user? This will DELETE all the user hosted domain names, files, and databases.") ,$url);
 	$domain_conf = "<a href=\"$confirmed_url\"><b>". _("Delete the user") ."</b></a><br><br>";
 	if(isset($data)){
 		$domain_conf .= "<h3>". _("Delete a user domain:") ."</h3><br>";
@@ -202,7 +231,7 @@ function drawEditAdmin($admin){
 				$domain_conf .= " - ";
 			}
 			$url = "?adm_login=$adm_login&adm_pass=$adm_pass&deluserdomain=$dom&rub=$rub";
-			$js_url = dtcJavascriptConfirmLink( _("Are you sure you want to delete this domain name ? This will erase all hosted files for this domain!!!") ,$url);
+			$js_url = dtcJavascriptConfirmLink( _("Are you sure you want to delete this domain name? This will DELETE all hosted files for this domain.") ,$url);
 			$domain_conf .= "<a href=\"$js_url\">$dom</a>";
 		}
 		$domain_conf .= "</b><br><br>";
@@ -294,7 +323,7 @@ function drawEditAdmin($admin){
  <div class=\"input_btn_right\"></div>
 </div></td></tr></table></form>";
 	}else{
-		$domain_conf .= _("To add a VPS, you need to setup some free IPs VPS in the general config and setup some VPS products.");
+		$domain_conf .= _("To add a VPS, you need to add IPs to the VPS IPs section in the general config as well as create at least one VPS product.");
 	}
 
 	// Deletion of dedicated
@@ -387,7 +416,7 @@ function drawDomainConfig($admin){
 		}
 		$dsc = array(
 			"table_name" => $pro_mysql_domain_table,
-			"title" => _("Configuration of the domains"),
+			"title" => _("Domain Configuration"),
 			"action" => "change_domain_config",
 			"forward" => array("rub","adm_login","adm_pass"),
 			"skip_deletion" => "yes",
@@ -470,7 +499,7 @@ function drawDomainConfig($admin){
 			$ret .= "<br><br>";
 			if( isset($_REQUEST["subdomain"]) && isHostname($_REQUEST["subdomain"]) ){
 				$ret .= "<u>". _("Subdomain") .": ".$_REQUEST["subdomain"].":</u><br>";
-				$ret .= _("Take care: no syntax checkings are done on your custom directives, doing a mistake here could lead to your web server not being able to restart!")."<br>";
+				$ret .= _("IMPORTANT: No syntax checking is done on your custom directives - a mistake here could lead to your web server not restarting properly.")."<br>";
 				$q = "SELECT customize_vhost FROM $pro_mysql_subdomain_table WHERE subdomain_name='".$_REQUEST["subdomain"]."' AND domain_name='".$_REQUEST["edithost"]."';";
 				$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 				$n = mysql_num_rows($r);
@@ -500,7 +529,7 @@ function drawDomainConfig($admin){
 					"legend" => _("ID")),
 				"customize_vhost" => array(
 					"type"=> "textarea",
-					"help"=> _("Custom apache directives. There is *no* syntax checking on this field!"),
+					"help"=> _("Custom apache directives. NOTE - There is *no* syntax checking on this field."),
 					"cols"=> "40",
 					"rows"=> "30",
 					"legend" => _("Custom apache directives")),
@@ -521,12 +550,12 @@ function drawDomainConfig($admin){
 					"legend" => _("Execution time")),
 				"php_upload_max_filesize" => array(
 					"type" => "text",
-					"help" => _("Maximum allowed size of uploaded file"),
+					"help" => _("Maximum uploaded file size"),
 					"size" => 2,
 					"legend" => _("Max upload file size")),
 				"php_post_max_size" => array(
 					"type" => "text",
-					"help" => _("Maximum allowed size of POST"),
+					"help" => _("Maximum POST data size"),
 					"size" => 2,
 					"legend" => _("Max POST file size")),
 				"php_session_auto_start" => array(
