@@ -30,10 +30,10 @@ function drawAdminTools_SSH($domain,$adm_path){
         // Build the popup values and display values arrays
 	$path_popup_vals = array();
 	$path_popup_disp = array();
-	$path_popup_vals[] = "$adm_path";
-	$path_popup_disp[] = "/ [ uses www ]";
-	$path_popup_vals[] = "$adm_path/$edit_domain";
-	$path_popup_disp[] = "/$edit_domain [ uses www ]";
+	//$path_popup_vals[] = "$adm_path";
+	//$path_popup_disp[] = "/ [ uses www ]";
+	//$path_popup_vals[] = "$adm_path/$edit_domain";
+	//$path_popup_disp[] = "/$edit_domain [ uses www ]";
 	$nbr_subdomains = sizeof($domain["subdomains"]);
 	for($i=0;$i<$nbr_subdomains;$i++){
 		$sub_name = $domain["subdomains"][$i]["name"];
@@ -57,7 +57,7 @@ function drawAdminTools_SSH($domain,$adm_path){
 		"where_list" => array(
 			"hostname" => $domain["name"]),
 		"check_unique" => array( "login" ),
-		"check_unique_msg" => _("There is already a ssh login by that name") ,
+		"check_unique_msg" => _("There is already an ssh login by that name") ,
 		"check_unique_use_where_list" => "no",
 		"order_by" => "login",
 		"cols" => array(
